# LelangMobil Web App - Versi 2025

Platform lelang mobil online terpercaya di Indonesia dengan fitur modern dan responsif.

## Fitur Utama

- **Sistem Autentikasi**: Login, register, verifikasi email, reset password
- **Manajemen Profil**: Update profil, ubah password, upload foto profil
- **Sistem Lelang**: Lelang kendaraan dengan penawaran real-time
- **Penawaran Otomatis**: Auto-bid untuk menawar secara otomatis
- **Manajemen Saldo**: Top up, penarikan, dan riwayat transaksi
- **Notifikasi Real-time**: Notifikasi dalam aplikasi dan push notification
- **WebSocket**: Komunikasi real-time untuk update lelang dan notifikasi
- **Tema Terang/Gelap**: Pilihan tema sesuai preferensi pengguna
- **Progressive Web App**: Dapat diinstal di perangkat dan bekerja offline
- **Responsif**: Tampilan yang optimal di semua perangkat

## Teknologi yang Digunakan

- **Backend**: PHP 7.4+
- **Database**: MySQL 5.7+
- **Frontend**: HTML5, CSS3, JavaScript
- **Framework CSS**: Bootstrap 5
- **Icon**: Font Awesome 5
- **Real-time**: WebSocket (Ratchet)
- **Service Worker**: Untuk PWA dan notifikasi push
- **Background Workers**: Untuk proses otomatis

## Struktur Direktori

- `admin/`: Panel administrasi
- `api/`: Endpoint API untuk AJAX dan WebSocket
- `assets/`: Gambar dan aset statis
- `config/`: File konfigurasi database dan aplikasi
- `css/`: File stylesheet
- `fonts/`: Font yang digunakan
- `images/`: Gambar untuk UI dan kendaraan
- `includes/`: Komponen yang dapat digunakan kembali
- `js/`: File JavaScript
- `logs/`: Log aplikasi
- `sql/`: File SQL untuk skema database
- `src/`: Kode sumber backend (WebSocket, Workers)
- `uploads/`: Direktori untuk file yang diunggah
- `vendor/`: Library pihak ketiga

## Instalasi

1. Clone repositori ini ke direktori web server Anda
2. Import file `database.sql` ke database MySQL Anda
3. Import file tambahan di direktori `sql/` untuk fitur tambahan
4. Konfigurasi koneksi database di `config/database.php`
5. Konfigurasi pengaturan email di `config/mailer.php`
6. Pastikan direktori `uploads/` dan `logs/` dapat ditulis oleh web server
7. Jalankan WebSocket server dengan perintah: `php src/WebSocket/server.php`
8. Jalankan background workers dengan perintah: `php src/Workers/run_workers.php`
9. Akses aplikasi melalui browser

## Fitur Real-time

Aplikasi ini menggunakan WebSocket untuk komunikasi real-time, yang memungkinkan:

1. **Update Lelang Langsung**: Penawaran baru langsung terlihat tanpa refresh
2. **Notifikasi Real-time**: Notifikasi instan untuk aktivitas penting
3. **Auto-bid**: Sistem penawaran otomatis yang bekerja secara real-time
4. **Status Transaksi**: Update status transaksi secara instan

## Progressive Web App

Aplikasi ini juga berfungsi sebagai Progressive Web App (PWA) dengan fitur:

1. **Dapat Diinstal**: Dapat diinstal di perangkat seperti aplikasi native
2. **Bekerja Offline**: Beberapa fitur tetap berfungsi tanpa koneksi internet
3. **Push Notification**: Notifikasi push bahkan ketika aplikasi tidak terbuka
4. **Caching**: Caching aset untuk performa lebih baik

## Keamanan

Aplikasi ini menerapkan beberapa praktik keamanan:

1. **Password Hashing**: Menggunakan algoritma hashing modern
2. **Sanitasi Input**: Mencegah XSS dan SQL injection
3. **CSRF Protection**: Mencegah serangan CSRF
4. **Session Security**: Regenerasi ID sesi secara periodik
5. **Prepared Statements**: Untuk semua query database

## Pemeliharaan dan Troubleshooting

Untuk memelihara dan memperbaiki masalah pada aplikasi:

1. Jalankan `error-fix.php` untuk memeriksa semua file dan memastikan tidak ada error
2. Jalankan `fix-functions.php` untuk memperbaiki masalah fungsi yang duplikat
3. Periksa log error di direktori `logs/` untuk informasi lebih lanjut tentang error
4. Gunakan `create_logs_dir.php` jika direktori logs belum ada

## Pencegahan Error

Aplikasi ini dilengkapi dengan beberapa fitur untuk mencegah error:

1. **Error Handler**: Menangkap dan mencatat semua error PHP
2. **Error Handler JavaScript**: Menangkap error JavaScript dan mencegah crash
3. **Page Loader**: Mencegah tampilan muncul dan tiba-tiba hilang
4. **Cleanup CSS dan JS**: Memperbaiki masalah tampilan dan fungsi yang duplikat

## Lisensi

Hak Cipta © 2025 LelangMobil. Semua hak dilindungi undang-undang.