<?php
/**
 * Favorite Vehicle API Endpoint
 */

require_once '../config/init.php';

// Ensure request is POST
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405);
    echo json_encode(['error' => 'Method not allowed']);
    exit;
}

// Ensure user is logged in
if (!isset($_SESSION['user_id'])) {
    http_response_code(401);
    echo json_encode(['error' => 'Unauthorized']);
    exit;
}

// Get JSON input
$input = json_decode(file_get_contents('php://input'), true);
$user_id = $_SESSION['user_id'];
$vehicle_id = isset($input['vehicle_id']) ? (int)$input['vehicle_id'] : 0;

if (!$vehicle_id) {
    http_response_code(400);
    echo json_encode(['error' => 'Invalid vehicle ID']);
    exit;
}

try {
    // Check if already favorited
    $check_sql = "SELECT favorite_id FROM favorite_vehicles WHERE user_id = ? AND vehicle_id = ?";
    $check_stmt = $conn->prepare($check_sql);
    $check_stmt->bind_param("ii", $user_id, $vehicle_id);
    $check_stmt->execute();
    $existing = $check_stmt->get_result()->fetch_assoc();
    
    if ($existing) {
        // Remove from favorites
        $delete_sql = "DELETE FROM favorite_vehicles WHERE favorite_id = ?";
        $delete_stmt = $conn->prepare($delete_sql);
        $delete_stmt->bind_param("i", $existing['favorite_id']);
        $delete_stmt->execute();
        
        echo json_encode([
            'success' => true,
            'is_favorite' => false,
            'message' => 'Removed from favorites'
        ]);
    } else {
        // Add to favorites
        $insert_sql = "INSERT INTO favorite_vehicles (user_id, vehicle_id) VALUES (?, ?)";
        $insert_stmt = $conn->prepare($insert_sql);
        $insert_stmt->bind_param("ii", $user_id, $vehicle_id);
        $insert_stmt->execute();
        
        echo json_encode([
            'success' => true,
            'is_favorite' => true,
            'message' => 'Added to favorites'
        ]);
    }
} catch (Throwable $e) {
    error_log("Favorite error: " . $e->getMessage());
    
    http_response_code(500);
    echo json_encode([
        'error' => 'Failed to update favorites',
        'message' => $e->getMessage()
    ]);
}