<?php
/**
 * Push Notification Subscribe API
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once '../config/init.php';

// Check if user is logged in
if (!is_logged_in()) {
    echo json_encode([
        'success' => false,
        'message' => 'Unauthorized'
    ]);
    exit;
}

// Check if request is POST
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    echo json_encode([
        'success' => false,
        'message' => 'Invalid request method'
    ]);
    exit;
}

// Get request body
$data = json_decode(file_get_contents('php://input'), true);

if (!$data || !isset($data['userId']) || !isset($data['subscription'])) {
    echo json_encode([
        'success' => false,
        'message' => 'Invalid request data'
    ]);
    exit;
}

$userId = $data['userId'];
$subscription = json_encode($data['subscription']);

// Verify user ID
if ($userId != $_SESSION['user_id']) {
    echo json_encode([
        'success' => false,
        'message' => 'User ID mismatch'
    ]);
    exit;
}

// Save subscription to database
try {
    // Check if subscription already exists
    $sql = "SELECT * FROM push_subscriptions WHERE user_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $userId);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        // Update existing subscription
        $sql = "UPDATE push_subscriptions SET subscription = ?, updated_at = NOW() WHERE user_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("si", $subscription, $userId);
    } else {
        // Insert new subscription
        $sql = "INSERT INTO push_subscriptions (user_id, subscription, created_at) VALUES (?, ?, NOW())";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("is", $userId, $subscription);
    }
    
    if ($stmt->execute()) {
        echo json_encode([
            'success' => true,
            'message' => 'Subscription saved'
        ]);
    } else {
        echo json_encode([
            'success' => false,
            'message' => 'Failed to save subscription'
        ]);
    }
} catch (Exception $e) {
    echo json_encode([
        'success' => false,
        'message' => 'Error: ' . $e->getMessage()
    ]);
}