<?php
/**
 * Rating API Endpoint
 */

require_once '../config/init.php';

// Ensure request is POST
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405);
    echo json_encode(['error' => 'Method not allowed']);
    exit;
}

// Ensure user is logged in
if (!isset($_SESSION['user_id'])) {
    http_response_code(401);
    echo json_encode(['error' => 'Unauthorized']);
    exit;
}

// Get JSON input
$input = json_decode(file_get_contents('php://input'), true);
$from_user_id = $_SESSION['user_id'];
$to_user_id = isset($input['seller_id']) ? (int)$input['seller_id'] : 0;
$rating = isset($input['rating']) ? (int)$input['rating'] : 0;
$comment = isset($input['comment']) ? trim($input['comment']) : '';

if (!$to_user_id || $rating < 1 || $rating > 5) {
    http_response_code(400);
    echo json_encode(['error' => 'Invalid input parameters']);
    exit;
}

try {
    // Check if user has already rated this seller
    $check_sql = "SELECT rating_id FROM user_ratings WHERE from_user_id = ? AND to_user_id = ?";
    $check_stmt = $conn->prepare($check_sql);
    $check_stmt->bind_param("ii", $from_user_id, $to_user_id);
    $check_stmt->execute();
    $existing = $check_stmt->get_result()->fetch_assoc();
    
    if ($existing) {
        // Update existing rating
        $update_sql = "UPDATE user_ratings SET rating = ?, comment = ? WHERE rating_id = ?";
        $update_stmt = $conn->prepare($update_sql);
        $update_stmt->bind_param("isi", $rating, $comment, $existing['rating_id']);
        $update_stmt->execute();
        
        $message = "Rating berhasil diperbarui";
    } else {
        // Insert new rating
        $insert_sql = "INSERT INTO user_ratings (from_user_id, to_user_id, rating, comment) VALUES (?, ?, ?, ?)";
        $insert_stmt = $conn->prepare($insert_sql);
        $insert_stmt->bind_param("iiis", $from_user_id, $to_user_id, $rating, $comment);
        $insert_stmt->execute();
        
        $message = "Rating berhasil dikirim";
    }
    
    // Calculate new average rating
    $avg_sql = "SELECT AVG(rating) as avg_rating FROM user_ratings WHERE to_user_id = ?";
    $avg_stmt = $conn->prepare($avg_sql);
    $avg_stmt->bind_param("i", $to_user_id);
    $avg_stmt->execute();
    $avg_rating = $avg_stmt->get_result()->fetch_assoc()['avg_rating'];
    
    echo json_encode([
        'success' => true,
        'message' => $message,
        'avg_rating' => round($avg_rating, 1)
    ]);
    
} catch (Throwable $e) {
    error_log("Rating error: " . $e->getMessage());
    
    http_response_code(500);
    echo json_encode([
        'error' => 'Failed to submit rating',
        'message' => $e->getMessage()
    ]);
}