<?php
/**
 * Email Functions
 * LelangMobil Web App - Versi 2025
 */

// Email settings
$email_settings = [
    'host' => 'mail.spacemail.com',
    'port' => 465,
    'username' => 'support@zap-hosting.pro',
    'password' => 'Arunk@123',
    'secure' => 'ssl',
    'from_email' => 'support@zap-hosting.pro',
    'from_name' => 'LelangMobil'
];

/**
 * Send email using PHP mail function
 * 
 * @param string $to Recipient email
 * @param string $subject Email subject
 * @param string $body Email body (HTML)
 * @param string $altBody Plain text alternative body
 * @return bool Success or failure
 */
function send_email($to, $subject, $body, $altBody = '') {
    global $email_settings;
    
    // Check if PHPMailer is installed
    if (!file_exists(__DIR__ . '/PHPMailer/src/PHPMailer.php')) {
        error_log("PHPMailer not found. Using native PHP mail function.");
        
        // Use PHP's mail function as fallback
        $from_email = $email_settings['from_email'];
        $from_name = $email_settings['from_name'];
        
        // Headers
        $headers = "MIME-Version: 1.0\r\n";
        $headers .= "Content-type: text/html; charset=UTF-8\r\n";
        $headers .= "From: {$from_name} <{$from_email}>\r\n";
        $headers .= "Reply-To: {$from_email}\r\n";
        $headers .= "X-Mailer: PHP/" . phpversion();
        
        // Send email
        return mail($to, $subject, $body, $headers);
    }
    
    // Use PHPMailer
    require_once __DIR__ . '/PHPMailer/src/Exception.php';
    require_once __DIR__ . '/PHPMailer/src/PHPMailer.php';
    require_once __DIR__ . '/PHPMailer/src/SMTP.php';
    
    $mail = new PHPMailer\PHPMailer\PHPMailer(true);
    
    try {
        // Server settings
        $mail->isSMTP();
        $mail->Host = $email_settings['host'];
        $mail->SMTPAuth = true;
        $mail->Username = $email_settings['username'];
        $mail->Password = $email_settings['password'];
        $mail->SMTPSecure = $email_settings['secure'];
        $mail->Port = $email_settings['port'];
        
        // Recipients
        $mail->setFrom($email_settings['from_email'], $email_settings['from_name']);
        $mail->addAddress($to);
        
        // Content
        $mail->isHTML(true);
        $mail->Subject = $subject;
        $mail->Body = $body;
        $mail->AltBody = $altBody ?: strip_tags($body);
        
        $mail->send();
        return true;
    } catch (Exception $e) {
        error_log("Email sending failed: " . $mail->ErrorInfo);
        return false;
    }
}

/**
 * Send verification email
 * 
 * @param object $conn Database connection
 * @param string $email Recipient email
 * @param string $token Verification token
 * @param int $user_id User ID
 * @return bool Success or failure
 */
function send_verification_email($conn, $email, $token, $user_id) {
    // Get user name
    $sql = "SELECT username, full_name FROM users WHERE user_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        $user = $result->fetch_assoc();
        $user_name = !empty($user['full_name']) ? $user['full_name'] : $user['username'];
        
        $subject = "Verifikasi Akun LelangMobil";
        
        $verification_url = get_base_url() . "/verify.php?token=" . $token;
        
        $body = '
        <div style="font-family: Arial, sans-serif; max-width: 600px; margin: 0 auto; padding: 20px; border: 1px solid #eee; border-radius: 10px;">
            <div style="text-align: center; margin-bottom: 20px;">
                <img src="' . get_base_url() . '/images/logo.png" alt="LelangMobil Logo" style="max-width: 200px;">
            </div>
            <h2 style="color: #4a6ee0;">Verifikasi Akun Anda</h2>
            <p>Halo <strong>' . $user_name . '</strong>,</p>
            <p>Terima kasih telah mendaftar di LelangMobil. Untuk menyelesaikan pendaftaran, silakan verifikasi email Anda dengan mengklik tombol di bawah ini:</p>
            <p style="text-align: center; margin: 30px 0;">
                <a href="' . $verification_url . '" style="background-color: #4a6ee0; color: white; padding: 12px 25px; text-decoration: none; border-radius: 5px; font-weight: bold;">Verifikasi Email</a>
            </p>
            <p>Atau salin dan tempel URL berikut ke browser Anda:</p>
            <p style="background-color: #f5f5f5; padding: 10px; border-radius: 5px; word-break: break-all;">' . $verification_url . '</p>
            <p>Link verifikasi ini akan kedaluwarsa dalam 24 jam.</p>
            <p>Jika Anda tidak mendaftar di LelangMobil, abaikan email ini.</p>
            <div style="margin-top: 30px; padding-top: 20px; border-top: 1px solid #eee; font-size: 12px; color: #777;">
                <p>Email ini dikirim secara otomatis, mohon tidak membalas email ini.</p>
                <p>&copy; ' . date('Y') . ' LelangMobil. All rights reserved.</p>
            </div>
        </div>';
        
        return send_email($email, $subject, $body);
    }
    
    return false;
}

/**
 * Send password reset email
 * 
 * @param object $conn Database connection
 * @param string $email Recipient email
 * @param string $token Reset token
 * @return bool Success or failure
 */
function send_password_reset_email($conn, $email, $token) {
    // Get user name
    $sql = "SELECT username, full_name FROM users WHERE email = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        $user = $result->fetch_assoc();
        $user_name = !empty($user['full_name']) ? $user['full_name'] : $user['username'];
        
        $subject = "Reset Password LelangMobil";
        
        $reset_url = get_base_url() . "/reset-password.php?token=" . $token;
        
        $body = '
        <div style="font-family: Arial, sans-serif; max-width: 600px; margin: 0 auto; padding: 20px; border: 1px solid #eee; border-radius: 10px;">
            <div style="text-align: center; margin-bottom: 20px;">
                <img src="' . get_base_url() . '/images/logo.png" alt="LelangMobil Logo" style="max-width: 200px;">
            </div>
            <h2 style="color: #4a6ee0;">Reset Password</h2>
            <p>Halo <strong>' . $user_name . '</strong>,</p>
            <p>Kami menerima permintaan untuk reset password akun LelangMobil Anda. Klik tombol di bawah ini untuk melanjutkan:</p>
            <p style="text-align: center; margin: 30px 0;">
                <a href="' . $reset_url . '" style="background-color: #4a6ee0; color: white; padding: 12px 25px; text-decoration: none; border-radius: 5px; font-weight: bold;">Reset Password</a>
            </p>
            <p>Atau salin dan tempel URL berikut ke browser Anda:</p>
            <p style="background-color: #f5f5f5; padding: 10px; border-radius: 5px; word-break: break-all;">' . $reset_url . '</p>
            <p>Link reset password ini akan kedaluwarsa dalam 1 jam.</p>
            <p>Jika Anda tidak meminta reset password, abaikan email ini dan password Anda akan tetap sama.</p>
            <div style="margin-top: 30px; padding-top: 20px; border-top: 1px solid #eee; font-size: 12px; color: #777;">
                <p>Email ini dikirim secara otomatis, mohon tidak membalas email ini.</p>
                <p>&copy; ' . date('Y') . ' LelangMobil. All rights reserved.</p>
            </div>
        </div>';
        
        return send_email($email, $subject, $body);
    }
    
    return false;
}

/**
 * Send notification email
 * 
 * @param object $conn Database connection
 * @param int $user_id User ID
 * @param string $subject Email subject
 * @param string $message Email message
 * @param string $action_url Optional action URL
 * @param string $action_text Optional action text
 * @return bool Success or failure
 */
function send_notification_email($conn, $user_id, $subject, $message, $action_url = '', $action_text = '') {
    // Get user email and name
    $sql = "SELECT email, username, full_name FROM users WHERE user_id = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    $result = $stmt->get_result();
    
    if ($result->num_rows > 0) {
        $user = $result->fetch_assoc();
        $user_email = $user['email'];
        $user_name = !empty($user['full_name']) ? $user['full_name'] : $user['username'];
        
        $body = '
        <div style="font-family: Arial, sans-serif; max-width: 600px; margin: 0 auto; padding: 20px; border: 1px solid #eee; border-radius: 10px;">
            <div style="text-align: center; margin-bottom: 20px;">
                <img src="' . get_base_url() . '/images/logo.png" alt="LelangMobil Logo" style="max-width: 200px;">
            </div>
            <h2 style="color: #4a6ee0;">' . $subject . '</h2>
            <p>Halo <strong>' . $user_name . '</strong>,</p>
            <p>' . $message . '</p>';
        
        if (!empty($action_url) && !empty($action_text)) {
            $body .= '
            <p style="text-align: center; margin: 30px 0;">
                <a href="' . $action_url . '" style="background-color: #4a6ee0; color: white; padding: 12px 25px; text-decoration: none; border-radius: 5px; font-weight: bold;">' . $action_text . '</a>
            </p>';
        }
        
        $body .= '
            <div style="margin-top: 30px; padding-top: 20px; border-top: 1px solid #eee; font-size: 12px; color: #777;">
                <p>Email ini dikirim secara otomatis, mohon tidak membalas email ini.</p>
                <p>&copy; ' . date('Y') . ' LelangMobil. All rights reserved.</p>
            </div>
        </div>';
        
        return send_email($user_email, $subject, $body);
    }
    
    return false;
}
?>