<?php
/**
 * Error Page
 * LelangMobil Web App - Versi 2025
 */

// Jika tidak ada error, tampilkan error 404
if (!isset($error) && isset($_GET['code'])) {
    $code = (int)$_GET['code'];
    
    switch ($code) {
        case 400:
            $error_title = 'Bad Request';
            $error_message = 'Permintaan tidak valid.';
            break;
        case 401:
            $error_title = 'Unauthorized';
            $error_message = 'Anda tidak memiliki izin untuk mengakses halaman ini.';
            break;
        case 403:
            $error_title = 'Forbidden';
            $error_message = 'Akses ditolak.';
            break;
        case 404:
            $error_title = 'Not Found';
            $error_message = 'Halaman yang Anda cari tidak ditemukan.';
            break;
        case 500:
            $error_title = 'Internal Server Error';
            $error_message = 'Terjadi kesalahan pada server.';
            break;
        default:
            $error_title = 'Error';
            $error_message = 'Terjadi kesalahan.';
            break;
    }
} else if (!isset($error)) {
    $error_title = 'Error';
    $error_message = 'Terjadi kesalahan yang tidak diketahui.';
}

// Set page title
$page_title = "Error - LelangMobil";

// Coba untuk include header
try {
    include("includes/header.php");
} catch (Exception $e) {
    // Jika gagal, tampilkan header minimal
    echo '<!DOCTYPE html>
    <html lang="id">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title>Error - LelangMobil</title>
        <link rel="icon" href="images/icon.png" type="image/png">
        <style>
            body {
                font-family: "Segoe UI", Tahoma, Geneva, Verdana, sans-serif;
                background-color: #f5f7fa;
                color: #333;
                margin: 0;
                padding: 0;
                display: flex;
                flex-direction: column;
                min-height: 100vh;
            }
            
            .container {
                max-width: 1200px;
                margin: 0 auto;
                padding: 0 15px;
            }
            
            .error-container {
                display: flex;
                flex-direction: column;
                align-items: center;
                justify-content: center;
                text-align: center;
                padding: 5rem 1rem;
                min-height: 60vh;
            }
            
            .error-icon {
                font-size: 5rem;
                color: #dc3545;
                margin-bottom: 2rem;
            }
            
            .error-title {
                font-size: 2.5rem;
                font-weight: 700;
                margin-bottom: 1rem;
            }
            
            .error-message {
                font-size: 1.25rem;
                margin-bottom: 2rem;
                max-width: 600px;
            }
            
            .btn {
                display: inline-block;
                font-weight: 500;
                text-align: center;
                white-space: nowrap;
                vertical-align: middle;
                user-select: none;
                border: 1px solid transparent;
                padding: 0.75rem 1.5rem;
                font-size: 1rem;
                line-height: 1.5;
                border-radius: 0.5rem;
                transition: all 0.3s ease;
                text-decoration: none;
            }
            
            .btn-primary {
                color: #fff;
                background-color: #4a6ee0;
                border-color: #4a6ee0;
            }
            
            .btn-primary:hover {
                background-color: #3a5ed0;
                border-color: #3a5ed0;
                transform: translateY(-2px);
                box-shadow: 0 5px 15px rgba(74, 110, 224, 0.4);
            }
        </style>
    </head>
    <body>
        <div class="container">';
}
?>

<div class="error-container">
    <div class="error-icon">
        <i class="fa fa-exclamation-triangle"></i>
    </div>
    <h1 class="error-title"><?php echo isset($error_title) ? $error_title : 'Error'; ?></h1>
    <p class="error-message"><?php echo isset($error_message) ? $error_message : 'Terjadi kesalahan.'; ?></p>
    <div>
        <a href="index.php" class="modern-btn modern-btn-primary">Kembali ke Beranda</a>
    </div>
</div>

<?php
// Coba untuk include footer
try {
    include("includes/footer.php");
} catch (Exception $e) {
    // Jika gagal, tampilkan footer minimal
    echo '</div>
    </body>
    </html>';
}
?>