<?php
/**
 * Fix Functions
 * LelangMobil Web App - Versi 2025
 * 
 * Script untuk memperbaiki masalah fungsi yang duplikat
 */

// Pesan error yang akan ditampilkan
$error_message = '';
$success_message = '';

// Cek apakah file functions.php dan init.php ada
if (!file_exists('config/functions.php') || !file_exists('config/init.php')) {
    $error_message = 'File functions.php atau init.php tidak ditemukan.';
} else {
    // Baca isi file functions.php
    $functions_content = file_get_contents('config/functions.php');
    
    // Baca isi file init.php
    $init_content = file_get_contents('config/init.php');
    
    // Cek apakah ada fungsi format_date di init.php
    if (strpos($init_content, 'function format_date') !== false) {
        // Hapus fungsi format_date dari init.php
        $init_content = preg_replace('/\/\/ Fungsi untuk format tanggal\s*if \(!function_exists\(\'format_date\'\)\) \{\s*function format_date\([^}]*\}\s*\}\s*/s', '', $init_content);
        
        // Tulis kembali file init.php
        if (file_put_contents('config/init.php', $init_content)) {
            $success_message .= 'Berhasil menghapus fungsi format_date dari init.php.<br>';
        } else {
            $error_message .= 'Gagal menghapus fungsi format_date dari init.php.<br>';
        }
    } else {
        $success_message .= 'Tidak ada fungsi format_date di init.php.<br>';
    }
    
    // Cek apakah ada fungsi clean_input di functions.php
    if (strpos($functions_content, 'function clean_input') === false) {
        // Tambahkan fungsi clean_input ke functions.php
        $clean_input_function = "\n// Fungsi untuk sanitasi input\nif (!function_exists('clean_input')) {\n    function clean_input(\$data) {\n        \$data = trim(\$data);\n        \$data = stripslashes(\$data);\n        \$data = htmlspecialchars(\$data);\n        return \$data;\n    }\n}\n";
        
        // Tambahkan fungsi clean_input setelah tag pembuka PHP
        $functions_content = preg_replace('/^<\?php/', "<?php{$clean_input_function}", $functions_content);
        
        // Tulis kembali file functions.php
        if (file_put_contents('config/functions.php', $functions_content)) {
            $success_message .= 'Berhasil menambahkan fungsi clean_input ke functions.php.<br>';
        } else {
            $error_message .= 'Gagal menambahkan fungsi clean_input ke functions.php.<br>';
        }
    } else {
        $success_message .= 'Fungsi clean_input sudah ada di functions.php.<br>';
    }
    
    // Cek apakah ada fungsi get_base_url di functions.php
    if (strpos($functions_content, 'function get_base_url') === false) {
        // Tambahkan fungsi get_base_url ke functions.php
        $get_base_url_function = "\n// Fungsi untuk mendapatkan base URL\nif (!function_exists('get_base_url')) {\n    function get_base_url() {\n        \$protocol = isset(\$_SERVER['HTTPS']) && \$_SERVER['HTTPS'] === 'on' ? 'https://' : 'http://';\n        \$host = \$_SERVER['HTTP_HOST'];\n        \$path = dirname(\$_SERVER['SCRIPT_NAME']);\n        \$path = str_replace('\\\\', '/', \$path);\n        \$path = \$path !== '/' ? rtrim(\$path, '/') : '';\n        \n        return \$protocol . \$host . \$path;\n    }\n}\n";
        
        // Tambahkan fungsi get_base_url setelah tag pembuka PHP
        $functions_content = preg_replace('/^<\?php/', "<?php{$get_base_url_function}", $functions_content);
        
        // Tulis kembali file functions.php
        if (file_put_contents('config/functions.php', $functions_content)) {
            $success_message .= 'Berhasil menambahkan fungsi get_base_url ke functions.php.<br>';
        } else {
            $error_message .= 'Gagal menambahkan fungsi get_base_url ke functions.php.<br>';
        }
    } else {
        $success_message .= 'Fungsi get_base_url sudah ada di functions.php.<br>';
    }
    
    // Hapus fungsi get_base_url dan clean_input dari init.php jika ada
    if (strpos($init_content, 'function get_base_url') !== false) {
        $init_content = preg_replace('/\/\/ Fungsi untuk mendapatkan base URL\s*if \(!function_exists\(\'get_base_url\'\)\) \{\s*function get_base_url\([^}]*\}\s*\}\s*/s', '', $init_content);
        
        // Tulis kembali file init.php
        if (file_put_contents('config/init.php', $init_content)) {
            $success_message .= 'Berhasil menghapus fungsi get_base_url dari init.php.<br>';
        } else {
            $error_message .= 'Gagal menghapus fungsi get_base_url dari init.php.<br>';
        }
    }
    
    if (strpos($init_content, 'function clean_input') !== false) {
        $init_content = preg_replace('/\/\/ Fungsi untuk sanitasi input\s*if \(!function_exists\(\'clean_input\'\)\) \{\s*function clean_input\([^}]*\}\s*\}\s*/s', '', $init_content);
        
        // Tulis kembali file init.php
        if (file_put_contents('config/init.php', $init_content)) {
            $success_message .= 'Berhasil menghapus fungsi clean_input dari init.php.<br>';
        } else {
            $error_message .= 'Gagal menghapus fungsi clean_input dari init.php.<br>';
        }
    }
    
    // Pastikan file resend-verification.php menggunakan init.php
    if (file_exists('resend_verification.php')) {
        $resend_content = file_get_contents('resend_verification.php');
        
        // Ganti include dengan init.php
        $resend_content = preg_replace('/require_once \'config\/database\.php\';(\s*)require_once \'config\/functions\.php\';(\s*)require_once \'config\/mailer\.php\';/s', 'require_once \'config/init.php\';', $resend_content);
        
        // Tulis kembali file resend_verification.php
        if (file_put_contents('resend_verification.php', $resend_content)) {
            $success_message .= 'Berhasil memperbarui file resend_verification.php.<br>';
        } else {
            $error_message .= 'Gagal memperbarui file resend_verification.php.<br>';
        }
    }
}

// Set page title
$page_title = "Fix Functions - LelangMobil";

// Include header
include("includes/header.php");
?>

<div class="container py-5">
    <div class="row">
        <div class="col-lg-8 offset-lg-2">
            <div class="modern-card">
                <div class="modern-card-header">
                    <h2>Fix Functions</h2>
                </div>
                <div class="modern-card-body">
                    <?php if (!empty($error_message)): ?>
                        <div class="modern-alert modern-alert-danger mb-4">
                            <i class="fa fa-exclamation-circle"></i>
                            <div><?php echo $error_message; ?></div>
                        </div>
                    <?php endif; ?>
                    
                    <?php if (!empty($success_message)): ?>
                        <div class="modern-alert modern-alert-success mb-4">
                            <i class="fa fa-check-circle"></i>
                            <div><?php echo $success_message; ?></div>
                        </div>
                    <?php endif; ?>
                    
                    <p>Script ini memperbaiki masalah fungsi yang duplikat di file functions.php dan init.php.</p>
                    
                    <div class="mt-4">
                        <a href="index.php" class="modern-btn modern-btn-primary">Kembali ke Beranda</a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<?php include("includes/footer.php"); ?>