<?php
/**
 * Active Auctions Widget
 * LelangMobil Web App - Versi 2025
 */

// Get active auctions
try {
    $auctions_sql = "SELECT v.*, 
                    COALESCE(v.brand, v.make) as brand, 
                    COALESCE(v.image_main, v.image) as image, 
                    COALESCE(v.starting_price, v.start_price) as starting_price, 
                    COALESCE(v.current_bid, v.current_price) as current_bid, 
                    COALESCE(v.end_date, v.auction_end) as end_date,
                    (SELECT COUNT(*) FROM bids WHERE vehicle_id = v.vehicle_id) as bid_count,
                    (SELECT MAX(bid_id) FROM bids WHERE vehicle_id = v.vehicle_id AND bidder_id = ?) as user_bid_id
                    FROM vehicles v 
                    WHERE v.status = 'active' 
                    ORDER BY end_date ASC 
                    LIMIT 3";
    $auctions_stmt = $conn->prepare($auctions_sql);
    $auctions_stmt->bind_param("i", $user_id);
    $auctions_stmt->execute();
    $auctions_result = $auctions_stmt->get_result();
} catch (Exception $e) {
    error_log("Error in active-auctions-widget.php: " . $e->getMessage());
    $auctions_result = null;
}
?>

<div class="widget-card mb-4 animate">
    <div class="widget-card-header">
        <h5 class="widget-card-title">Lelang Aktif</h5>
        <a href="auctions.php" class="modern-btn modern-btn-outline btn-sm">Lihat Semua</a>
    </div>
    <div class="widget-card-body">
        <?php if ($auctions_result && $auctions_result->num_rows > 0): ?>
            <div class="row">
                <?php while ($auction = $auctions_result->fetch_assoc()): ?>
                    <div class="col-md-4 mb-4 mb-md-0">
                        <div class="vehicle-card h-100">
                            <div class="vehicle-card-image">
                                <?php if (!empty($auction['image']) && file_exists($auction['image'])): ?>
                                    <img src="<?php echo htmlspecialchars($auction['image']); ?>" alt="<?php echo htmlspecialchars($auction['brand'] . ' ' . $auction['model']); ?>" class="img-fluid">
                                <?php else: ?>
                                    <img src="images/no-image.svg" alt="No Image" class="img-fluid">
                                <?php endif; ?>
                                
                                <?php if (!empty($auction['user_bid_id'])): ?>
                                    <div class="vehicle-card-status">
                                        <span class="modern-badge modern-badge-primary">Anda Bid</span>
                                    </div>
                                <?php endif; ?>
                            </div>
                            <div class="vehicle-card-content">
                                <h5 class="vehicle-card-title"><?php echo htmlspecialchars($auction['brand'] . ' ' . $auction['model']); ?></h5>
                                <div class="vehicle-card-price"><?php echo format_money($auction['current_bid']); ?></div>
                                <div class="vehicle-card-info">
                                    <div class="vehicle-card-info-item">
                                        <i class="fa fa-gavel"></i> <?php echo number_format($auction['bid_count']); ?> bid
                                    </div>
                                    <div class="vehicle-card-info-item">
                                        <i class="fa fa-clock"></i> <?php echo get_remaining_time($auction['end_date']); ?>
                                    </div>
                                </div>
                                <div class="vehicle-card-footer">
                                    <a href="vehicle.php?id=<?php echo $auction['vehicle_id']; ?>" class="modern-btn modern-btn-primary btn-sm">Detail</a>
                                    <a href="vehicle.php?id=<?php echo $auction['vehicle_id']; ?>#bid" class="modern-btn modern-btn-outline btn-sm">Bid</a>
                                </div>
                            </div>
                        </div>
                    </div>
                <?php endwhile; ?>
            </div>
        <?php else: ?>
            <div class="text-center py-4">
                <div class="mb-3">
                    <i class="fa fa-car fa-3x text-muted"></i>
                </div>
                <h5>Tidak Ada Lelang Aktif</h5>
                <p class="text-muted">Saat ini tidak ada lelang yang sedang berlangsung.</p>
                <a href="auctions.php" class="modern-btn modern-btn-primary">Lihat Semua Lelang</a>
            </div>
        <?php endif; ?>
    </div>
</div>