<?php
/**
 * Wallet Tab Component
 * LelangMobil Web App - Versi 2025
 */

// Get wallet statistics
$wallet_stats = [
    'total_deposit' => $transaction_stats['total_deposit'] ?? 0,
    'total_withdrawal' => $transaction_stats['total_withdrawal'] ?? 0,
    'pending_transactions' => $transaction_stats['pending_transactions'] ?? 0,
    'balance' => $user['balance'] ?? 0
];

// Get recent transactions for wallet
$wallet_transactions = [];
try {
    $wallet_transactions_sql = "SELECT * FROM transactions 
                              WHERE user_id = ? AND (type = 'deposit' OR type = 'withdrawal') 
                              ORDER BY created_at DESC LIMIT 5";
    $wallet_transactions_stmt = $conn->prepare($wallet_transactions_sql);
    $wallet_transactions_stmt->bind_param("i", $user_id);
    $wallet_transactions_stmt->execute();
    $wallet_transactions_result = $wallet_transactions_stmt->get_result();
    
    while ($row = $wallet_transactions_result->fetch_assoc()) {
        $wallet_transactions[] = $row;
    }
} catch (Throwable $e) {
    // Handle error silently
}
?>

<div class="tab-pane fade" id="wallet-tab" role="tabpanel" aria-labelledby="wallet-tab">
    <div class="tab-header d-flex justify-content-between align-items-center mb-4">
        <h4>Saldo & Transaksi</h4>
        <div>
            <a href="topup-modern.php" class="modern-button modern-button-primary modern-button-sm me-2">
                <i class="fa fa-plus-circle me-2"></i>Top Up
            </a>
            <a href="withdraw-modern.php" class="modern-button modern-button-outline modern-button-sm">
                <i class="fa fa-minus-circle me-2"></i>Tarik
            </a>
        </div>
    </div>
    
    <!-- Wallet Stats -->
    <div class="row mb-4">
        <div class="col-md-6 mb-3">
            <div class="modern-card wallet-balance-card h-100">
                <div class="modern-card-body">
                    <div class="d-flex align-items-center">
                        <div class="wallet-icon me-3">
                            <i class="fa fa-wallet"></i>
                        </div>
                        <div>
                            <h6 class="text-muted mb-1">Saldo Saat Ini</h6>
                            <h3 class="mb-0"><?php echo format_money($wallet_stats['balance']); ?></h3>
                        </div>
                    </div>
                    
                    <div class="wallet-actions mt-3">
                        <a href="topup-modern.php" class="btn btn-sm btn-primary me-2">
                            <i class="fa fa-plus-circle me-1"></i> Top Up
                        </a>
                        <a href="withdraw-modern.php" class="btn btn-sm btn-outline-primary">
                            <i class="fa fa-minus-circle me-1"></i> Tarik
                        </a>
                    </div>
                </div>
            </div>
        </div>
        
        <div class="col-md-6 mb-3">
            <div class="modern-card h-100">
                <div class="modern-card-body">
                    <div class="row">
                        <div class="col-6">
                            <div class="wallet-stat">
                                <div class="wallet-stat-icon deposit">
                                    <i class="fa fa-arrow-down"></i>
                                </div>
                                <div class="wallet-stat-info">
                                    <h6 class="text-muted mb-1">Total Top Up</h6>
                                    <h5 class="mb-0"><?php echo format_money($wallet_stats['total_deposit']); ?></h5>
                                </div>
                            </div>
                        </div>
                        <div class="col-6">
                            <div class="wallet-stat">
                                <div class="wallet-stat-icon withdraw">
                                    <i class="fa fa-arrow-up"></i>
                                </div>
                                <div class="wallet-stat-info">
                                    <h6 class="text-muted mb-1">Total Penarikan</h6>
                                    <h5 class="mb-0"><?php echo format_money($wallet_stats['total_withdrawal']); ?></h5>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <?php if ($wallet_stats['pending_transactions'] > 0): ?>
                    <div class="wallet-pending-alert mt-3">
                        <div class="alert alert-warning mb-0">
                            <i class="fa fa-exclamation-circle me-2"></i>
                            <span>Anda memiliki <?php echo $wallet_stats['pending_transactions']; ?> transaksi yang sedang diproses</span>
                        </div>
                    </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
    
    <!-- Recent Wallet Transactions -->
    <div class="modern-card">
        <div class="modern-card-header">
            <h5 class="modern-card-title">Transaksi Terbaru</h5>
            <a href="transactions-modern.php?type=deposit" class="modern-card-link">Lihat Semua</a>
        </div>
        <div class="modern-card-body p-0">
            <?php if (empty($wallet_transactions)): ?>
            <div class="text-center py-4">
                <p class="text-muted mb-0">Belum ada transaksi saldo.</p>
            </div>
            <?php else: ?>
            <div class="table-responsive">
                <table class="table modern-table mb-0">
                    <thead>
                        <tr>
                            <th>Tanggal</th>
                            <th>Jenis</th>
                            <th>Jumlah</th>
                            <th>Status</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($wallet_transactions as $transaction): ?>
                        <tr>
                            <td><?php echo date('d M Y H:i', strtotime($transaction['created_at'])); ?></td>
                            <td>
                                <?php if ($transaction['type'] == 'deposit'): ?>
                                <span class="badge bg-success">Top Up</span>
                                <?php else: ?>
                                <span class="badge bg-warning">Penarikan</span>
                                <?php endif; ?>
                            </td>
                            <td>
                                <?php 
                                $amount_class = $transaction['type'] == 'deposit' ? 'text-success' : 'text-danger';
                                $prefix = $transaction['type'] == 'deposit' ? '+' : '-';
                                echo '<span class="'.$amount_class.'">'.$prefix.' '.format_money($transaction['amount']).'</span>'; 
                                ?>
                            </td>
                            <td>
                                <?php 
                                switch ($transaction['status']) {
                                    case 'completed':
                                        echo '<span class="badge bg-success">Selesai</span>';
                                        break;
                                    case 'pending':
                                        echo '<span class="badge bg-warning">Menunggu</span>';
                                        break;
                                    case 'rejected':
                                        echo '<span class="badge bg-danger">Ditolak</span>';
                                        break;
                                    default:
                                        echo '<span class="badge bg-secondary">'.$transaction['status'].'</span>';
                                }
                                ?>
                            </td>
                        </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            </div>
            <?php endif; ?>
        </div>
    </div>
</div>

<style>
.wallet-balance-card {
    background: linear-gradient(135deg, #4a6ee0, #7a54d8);
    color: white;
}

.wallet-icon {
    width: 50px;
    height: 50px;
    border-radius: 50%;
    background-color: rgba(255, 255, 255, 0.2);
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 1.5rem;
}

.wallet-actions .btn-sm {
    padding: 0.25rem 0.75rem;
    font-size: 0.875rem;
}

.wallet-stat {
    display: flex;
    align-items: center;
    margin-bottom: 15px;
}

.wallet-stat-icon {
    width: 40px;
    height: 40px;
    border-radius: 50%;
    display: flex;
    align-items: center;
    justify-content: center;
    margin-right: 10px;
    font-size: 1rem;
}

.wallet-stat-icon.deposit {
    background-color: rgba(40, 167, 69, 0.1);
    color: #28a745;
}

.wallet-stat-icon.withdraw {
    background-color: rgba(220, 53, 69, 0.1);
    color: #dc3545;
}

.modern-table {
    margin-bottom: 0;
}

.modern-table th {
    background-color: rgba(0,0,0,0.02);
    font-weight: 600;
    padding: 0.75rem 1rem;
}

.modern-table td {
    padding: 0.75rem 1rem;
    vertical-align: middle;
}

.modern-table tr:last-child td {
    border-bottom: none;
}
</style>