/**
 * Modern Dashboard JS
 * Interaktivitas dan efek untuk LelangMobil Dashboard
 * Version: 1.0 (2025-05-02)
 */

document.addEventListener('DOMContentLoaded', function() {
    // Menerapkan kelas modern ke elemen dashboard
    applyModernClasses();
    
    // Menambahkan efek ripple ke tombol
    initRippleEffect();
    
    // Menangani toggle sidebar di mobile
    initSidebarToggle();
    
    // Statistik AnimateCount
    initCountAnimation();
    
    // Menambahkan efek smooth scroll
    initSmoothScrolling();
    
    // Tooltip Bootstrap
    initTooltips();
    
    // Menambahkan efek fade-in untuk semua stat cards
    addFadeInEffect();
    
    // Menangani transisi tab dengan lebih mulus
    initSmoothTabTransition();
    
    // Dark mode toggle (jika ada)
    initDarkModeToggle();
    
    console.log('Modern dashboard effects initialized');
});

/**
 * Menerapkan kelas-kelas modern ke elemen dashboard
 */
function applyModernClasses() {
    // Menambahkan kelas glass-card ke semua premium-card
    document.querySelectorAll('.premium-card:not(.topup-panel):not(.withdraw-panel)').forEach(card => {
        card.classList.add('glass-card');
    });
    
    // Menambahkan kelas hover-lift ke semua stat-card
    document.querySelectorAll('.stat-card').forEach(card => {
        card.classList.add('hover-lift');
    });
    
    // Menambahkan kelas modern ke semua tabel
    document.querySelectorAll('.premium-table').forEach(table => {
        table.classList.add('table-modern');
    });
    
    // Input fields modern
    document.querySelectorAll('input[type="text"], input[type="email"], input[type="password"], textarea, select').forEach(input => {
        if (!input.classList.contains('form-select') && !input.classList.contains('form-control')) {
            input.classList.add('modern-input');
        }
    });
    
    // Buttons modern
    document.querySelectorAll('.btn-primary, .btn-success, .btn-info, .premium-btn').forEach(btn => {
        btn.classList.add('btn-modern');
    });
    
    // Menambahkan kelas badge-modern ke badge
    document.querySelectorAll('.badge').forEach(badge => {
        if (badge.classList.contains('premium-badge-success')) {
            badge.classList.add('badge-modern-success');
        } else if (badge.classList.contains('premium-badge-warning')) {
            badge.classList.add('badge-modern-warning');
        } else if (badge.classList.contains('premium-badge-danger')) {
            badge.classList.add('badge-modern-danger');
        } else if (badge.classList.contains('premium-badge-info')) {
            badge.classList.add('badge-modern-info');
        }
    });
    
    // Tambahkan kelas untuk empty states
    document.querySelectorAll('.empty-state').forEach(emptyState => {
        emptyState.classList.add('empty-state-modern');
    });
}

/**
 * Efek ripple untuk tombol
 */
function initRippleEffect() {
    document.querySelectorAll('.btn, .nav-link, .quick-action-link').forEach(button => {
        button.addEventListener('click', function(e) {
            // Posisi klik relatif terhadap elemen
            const rect = button.getBoundingClientRect();
            const x = e.clientX - rect.left;
            const y = e.clientY - rect.top;
            
            // Buat elemen ripple
            const ripple = document.createElement('span');
            ripple.classList.add('ripple');
            ripple.style.left = `${x}px`;
            ripple.style.top = `${y}px`;
            
            // Tambahkan ripple ke tombol
            button.appendChild(ripple);
            
            // Hapus ripple setelah animasi selesai
            setTimeout(() => {
                button.removeChild(ripple);
            }, 600);
        });
    });
    
    // Tambahkan CSS untuk ripple jika belum ada
    if (!document.getElementById('ripple-style')) {
        const style = document.createElement('style');
        style.id = 'ripple-style';
        style.textContent = `
            .btn, .nav-link, .quick-action-link {
                position: relative;
                overflow: hidden;
            }
            .ripple {
                position: absolute;
                border-radius: 50%;
                background-color: rgba(255, 255, 255, 0.5);
                transform: scale(0);
                animation: ripple 0.6s linear;
                pointer-events: none;
                width: 100px;
                height: 100px;
                transform: translate(-50%, -50%);
            }
            @keyframes ripple {
                0% {
                    transform: translate(-50%, -50%) scale(0);
                    opacity: 1;
                }
                100% {
                    transform: translate(-50%, -50%) scale(4);
                    opacity: 0;
                }
            }
        `;
        document.head.appendChild(style);
    }
}

/**
 * Toggle sidebar di mobile
 */
function initSidebarToggle() {
    const sidebarToggler = document.querySelector('.sidebar-toggler');
    const sidebar = document.querySelector('.sidebar');
    
    if (sidebarToggler && sidebar) {
        sidebarToggler.addEventListener('click', function() {
            sidebar.classList.toggle('show');
            document.body.classList.toggle('sidebar-open');
        });
        
        // Close sidebar when clicking outside
        document.addEventListener('click', function(e) {
            if (sidebar.classList.contains('show') && 
                !sidebar.contains(e.target) && 
                e.target !== sidebarToggler) {
                sidebar.classList.remove('show');
                document.body.classList.remove('sidebar-open');
            }
        });
    }
}

/**
 * Animasi counter untuk angka statistik
 */
function initCountAnimation() {
    // Fungsi untuk menganimasikan penghitungan
    function animateCount(el, start, end, duration) {
        let startTime = null;
        const step = (timestamp) => {
            if (!startTime) startTime = timestamp;
            const progress = Math.min((timestamp - startTime) / duration, 1);
            const value = Math.floor(progress * (end - start) + start);
            el.textContent = formatCurrency(value);
            if (progress < 1) {
                window.requestAnimationFrame(step);
            }
        };
        window.requestAnimationFrame(step);
    }
    
    // Helper untuk format mata uang Indonesia
    function formatCurrency(value) {
        return new Intl.NumberFormat('id-ID').format(value);
    }
    
    // Cari semua elemen dengan data-count atribut
    document.querySelectorAll('[data-count]').forEach(el => {
        const finalValue = parseInt(el.getAttribute('data-count').replace(/\D/g, ''), 10);
        
        // Tambahkan ke IntersectionObserver untuk start animasi saat visible
        const observer = new IntersectionObserver((entries) => {
            entries.forEach(entry => {
                if (entry.isIntersecting) {
                    animateCount(el, 0, finalValue, 1500);
                    observer.unobserve(el);
                }
            });
        }, { threshold: 0.1 });
        
        observer.observe(el);
    });
    
    // Format nilai balance yang ada
    document.querySelectorAll('.balance-value, .stat-value, .wallet-total').forEach(el => {
        if (!el.hasAttribute('data-count')) {
            const text = el.textContent;
            // Jika mengandung Rp dan angka
            if (text.includes('Rp') && /\d/.test(text)) {
                // Ekstrak angka dan format ulang
                const numericValue = text.replace(/[^\d]/g, '');
                const formattedValue = `Rp ${formatCurrency(numericValue)}`;
                // Apply nilai yang diformat
                el.textContent = formattedValue;
            }
        }
    });
}

/**
 * Smooth scrolling untuk navigasi
 */
function initSmoothScrolling() {
    document.querySelectorAll('a[href^="#"]:not([data-bs-toggle])').forEach(anchor => {
        anchor.addEventListener('click', function(e) {
            const targetId = this.getAttribute('href');
            
            if (targetId === '#') return;
            
            const targetElement = document.querySelector(targetId);
            
            if (targetElement) {
                e.preventDefault();
                window.scrollTo({
                    top: targetElement.offsetTop - 70,
                    behavior: 'smooth'
                });
            }
        });
    });
}

/**
 * Bootstrap tooltips
 */
function initTooltips() {
    const tooltipTriggerList = document.querySelectorAll('[data-bs-toggle="tooltip"]');
    if (typeof bootstrap !== 'undefined' && bootstrap.Tooltip) {
        tooltipTriggerList.forEach(tooltipTriggerEl => {
            new bootstrap.Tooltip(tooltipTriggerEl);
        });
    }
}

/**
 * Efek fade-in untuk elemen saat scroll
 */
function addFadeInEffect() {
    // Tambahkan kelas fade-in ke elemen yang akan dianimasikan
    const animatedElements = document.querySelectorAll('.stat-card, .premium-card, .activity-item');
    
    // Set timeout untuk elemen yang sudah visible saat load
    setTimeout(() => {
        animatedElements.forEach((el, index) => {
            setTimeout(() => {
                el.classList.add('fade-in');
            }, index * 100); // Staggered effect
        });
    }, 300);
}

/**
 * Animasi saat berpindah tab
 */
function initSmoothTabTransition() {
    const tabLinks = document.querySelectorAll('[data-bs-toggle="tab"]');
    
    tabLinks.forEach(tabLink => {
        tabLink.addEventListener('shown.bs.tab', function(e) {
            const targetId = e.target.getAttribute('data-bs-target');
            const targetPane = document.querySelector(targetId);
            
            if (targetPane) {
                // Reset animasi dengan menghapus kelas
                const elements = targetPane.querySelectorAll('.premium-card, .stat-card');
                elements.forEach(el => el.classList.remove('fade-in'));
                
                // Trigger reflow
                void targetPane.offsetWidth;
                
                // Tambahkan kembali kelas animasi
                elements.forEach((el, index) => {
                    setTimeout(() => {
                        el.classList.add('fade-in');
                    }, 50 + (index * 100));
                });
            }
        });
    });
}

/**
 * Dark mode toggle
 */
function initDarkModeToggle() {
    const darkModeToggle = document.querySelector('.dark-mode-toggle');
    
    if (darkModeToggle) {
        // Check for saved preference
        const isDarkMode = localStorage.getItem('darkMode') === 'true';
        
        // Apply saved preference
        if (isDarkMode) {
            document.body.classList.add('dark-mode');
            darkModeToggle.classList.add('active');
        }
        
        // Toggle handler
        darkModeToggle.addEventListener('click', function() {
            document.body.classList.toggle('dark-mode');
            const isNowDark = document.body.classList.contains('dark-mode');
            localStorage.setItem('darkMode', isNowDark);
            darkModeToggle.classList.toggle('active', isNowDark);
        });
    }
}
