/**
 * Modern Notifications JS
 * LelangMobil Web App - Versi 2025
 */

document.addEventListener('DOMContentLoaded', function() {
    // Get notification container
    const notificationContainer = document.getElementById('live-notifications');
    
    // Reference to fake transactions data
    const transactions = window.fakeTransactions || [];
    
    // Avatars array for notification icons
    const avatarIcons = [
        'fa-user-circle',
        'fa-user-check',
        'fa-user-shield',
        'fa-user-tie',
        'fa-user-tag'
    ];
    
    // Actions with corresponding icons
    const actionIcons = {
        'memenangkan lelang': 'fa-trophy',
        'melakukan top up': 'fa-wallet',
        'mengajukan bid': 'fa-gavel',
        'mendaftar': 'fa-user-plus',
        'menyelesaikan pembayaran': 'fa-check-circle'
    };
    
    // Colors for notification avatars
    const avatarColors = [
        'linear-gradient(45deg, #3b82f6, #2563eb)', // Blue
        'linear-gradient(45deg, #8b5cf6, #6d28d9)', // Purple
        'linear-gradient(45deg, #ec4899, #db2777)', // Pink
        'linear-gradient(45deg, #10b981, #059669)', // Green
        'linear-gradient(45deg, #f59e0b, #d97706)', // Amber
        'linear-gradient(45deg, #ef4444, #dc2626)'  // Red
    ];
    
    // Function to create a notification element
    function createNotification(transaction) {
        // Create notification item
        const item = document.createElement('div');
        item.className = 'notification-item';
        
        // Get random avatar icon and color
        const avatarIcon = avatarIcons[Math.floor(Math.random() * avatarIcons.length)];
        const avatarColor = avatarColors[Math.floor(Math.random() * avatarColors.length)];
        
        // Get action icon
        const actionIcon = actionIcons[transaction.action] || 'fa-bell';
        
        // Create avatar with first letter
        const avatar = document.createElement('div');
        avatar.className = 'notification-avatar';
        avatar.style.background = avatarColor;
        avatar.innerHTML = `<i class="fas ${actionIcon}"></i>`;
        
        // Create content container
        const content = document.createElement('div');
        content.className = 'notification-content';
        
        // Create title with name
        const title = document.createElement('div');
        title.className = 'notification-title';
        
        // Create name span with premium badge for some users (random)
        const showBadge = Math.random() > 0.7;
        let badgeHTML = '';
        
        if (showBadge) {
            const badges = [
                '<span class="premium-badge badge-verified"><i class="fas fa-check-circle badge-icon"></i>Terverifikasi</span>',
                '<span class="premium-badge badge-premium"><i class="fas fa-crown badge-icon"></i>Premium</span>',
                '<span class="premium-badge badge-official"><i class="fas fa-shield-alt badge-icon"></i>Official</span>',
                '<span class="premium-badge badge-trusted"><i class="fas fa-award badge-icon"></i>Trusted</span>'
            ];
            badgeHTML = badges[Math.floor(Math.random() * badges.length)];
        }
        
        title.innerHTML = `${transaction.name} ${badgeHTML}`;
        
        // Create description
        const description = document.createElement('div');
        description.className = 'notification-description';
        
        // Build description based on action
        let descText = `telah ${transaction.action}`;
        
        if (transaction.item) {
            descText += ` <strong>${transaction.item}</strong>`;
        }
        
        if (transaction.amount) {
            descText += ` senilai <span class="notification-amount">Rp${transaction.amount}</span>`;
        }
        
        description.innerHTML = descText;
        
        // Create time
        const time = document.createElement('div');
        time.className = 'notification-time';
        time.innerHTML = `<i class="far fa-clock"></i> ${transaction.time} yang lalu`;
        
        // Create close button
        const close = document.createElement('div');
        close.className = 'notification-close';
        close.innerHTML = '<i class="fas fa-times"></i>';
        close.addEventListener('click', function(e) {
            e.stopPropagation();
            item.style.animation = 'fadeOut 0.5s forwards';
            setTimeout(() => {
                item.remove();
            }, 500);
        });
        
        // Add click event to entire notification
        item.addEventListener('click', function() {
            // Create a toast notification
            createToast(`${transaction.name} ${transaction.action} ${transaction.item || ''} ${transaction.amount ? 'Rp'+transaction.amount : ''}`);
        });
        
        // Assemble notification
        content.appendChild(title);
        content.appendChild(description);
        content.appendChild(time);
        
        item.appendChild(avatar);
        item.appendChild(content);
        item.appendChild(close);
        
        return item;
    }
    
    // Function to create toast notifications
    function createToast(message) {
        // Check if toast container exists
        let toastContainer = document.querySelector('.toast-container');
        
        if (!toastContainer) {
            // Create toast container
            toastContainer = document.createElement('div');
            toastContainer.className = 'toast-container position-fixed top-0 end-0 p-3';
            document.body.appendChild(toastContainer);
        }
        
        // Create toast
        const toast = document.createElement('div');
        toast.className = 'toast show';
        toast.setAttribute('role', 'alert');
        toast.setAttribute('aria-live', 'assertive');
        toast.setAttribute('aria-atomic', 'true');
        
        // Toast content
        toast.innerHTML = `
            <div class="toast-header">
                <i class="fas fa-bell me-2 text-primary"></i>
                <strong class="me-auto">Notifikasi</strong>
                <small>Baru saja</small>
                <button type="button" class="btn-close" data-bs-dismiss="toast" aria-label="Close"></button>
            </div>
            <div class="toast-body">
                ${message}
            </div>
        `;
        
        // Add toast to container
        toastContainer.appendChild(toast);
        
        // Auto-remove toast after 5 seconds
        setTimeout(() => {
            toast.classList.remove('show');
            setTimeout(() => {
                toast.remove();
            }, 500);
        }, 5000);
    }
    
    // Display initial notifications on page load (random 3 from the list)
    function showInitialNotifications() {
        if (transactions.length > 0 && notificationContainer) {
            // Shuffle array to get random transactions
            const shuffled = [...transactions].sort(() => 0.5 - Math.random());
            const selected = shuffled.slice(0, 3);
            
            // Display with delay
            selected.forEach((transaction, index) => {
                setTimeout(() => {
                    const notification = createNotification(transaction);
                    notificationContainer.prepend(notification);
                }, index * 1500);
            });
        }
    }
    
    // Show random notifications at intervals
    function startRandomNotifications() {
        if (transactions.length > 0 && notificationContainer) {
            setInterval(() => {
                // Only add new notification if less than 5 are currently displayed
                if (notificationContainer.children.length < 5) {
                    const randomIndex = Math.floor(Math.random() * transactions.length);
                    const notification = createNotification(transactions[randomIndex]);
                    notificationContainer.prepend(notification);
                    
                    // Remove oldest notification if more than 4
                    if (notificationContainer.children.length > 4) {
                        notificationContainer.lastChild.remove();
                    }
                }
            }, 12000); // Every 12 seconds
        }
    }
    
    // Initialize notifications
    showInitialNotifications();
    startRandomNotifications();
    
    // Add animation to trust badges and other elements
    function animateOnScroll() {
        const elements = document.querySelectorAll('.animate');
        
        const observer = new IntersectionObserver((entries) => {
            entries.forEach(entry => {
                if (entry.isIntersecting) {
                    entry.target.classList.add('animated');
                    observer.unobserve(entry.target);
                }
            });
        }, {
            threshold: 0.1
        });
        
        elements.forEach(element => {
            observer.observe(element);
        });
    }
    
    // Initialize animations
    animateOnScroll();
});
