/**
 * Responsive Handler
 * LelangMobil Web App - Versi 2025
 * 
 * File ini berisi fungsi-fungsi untuk menangani responsivitas
 */

document.addEventListener('DOMContentLoaded', function() {
    // Inisialisasi handler responsif
    initResponsiveHandlers();
    
    // Tambahkan event listener untuk resize window
    window.addEventListener('resize', function() {
        initResponsiveHandlers();
    });
});

/**
 * Inisialisasi handler responsif
 */
function initResponsiveHandlers() {
    // Perbaiki tabel responsif
    makeTablesResponsive();
    
    // Perbaiki navbar pada mobile
    fixMobileNavbar();
    
    // Perbaiki card pada mobile
    fixMobileCards();
    
    // Perbaiki form pada mobile
    fixMobileForms();
}

/**
 * Membuat tabel menjadi responsif
 */
function makeTablesResponsive() {
    const tables = document.querySelectorAll('table:not(.table-responsive)');
    
    tables.forEach(function(table) {
        // Cek apakah tabel sudah dalam container responsif
        if (!table.parentElement.classList.contains('table-responsive')) {
            // Buat container responsif
            const responsiveDiv = document.createElement('div');
            responsiveDiv.className = 'table-responsive';
            
            // Pindahkan tabel ke dalam container
            table.parentNode.insertBefore(responsiveDiv, table);
            responsiveDiv.appendChild(table);
        }
    });
}

/**
 * Perbaiki navbar pada mobile
 */
function fixMobileNavbar() {
    const navbarToggler = document.querySelector('.navbar-toggler');
    const navbarCollapse = document.querySelector('.navbar-collapse');
    
    if (navbarToggler && navbarCollapse) {
        // Pastikan event listener hanya ditambahkan sekali
        if (!navbarToggler.hasAttribute('data-listener-added')) {
            navbarToggler.addEventListener('click', function() {
                navbarCollapse.classList.toggle('show');
            });
            
            // Tandai bahwa event listener sudah ditambahkan
            navbarToggler.setAttribute('data-listener-added', 'true');
        }
        
        // Tambahkan event listener untuk menutup navbar saat klik di luar
        document.addEventListener('click', function(e) {
            if (navbarCollapse.classList.contains('show') && 
                !navbarCollapse.contains(e.target) && 
                e.target !== navbarToggler && 
                !navbarToggler.contains(e.target)) {
                navbarCollapse.classList.remove('show');
            }
        });
    }
}

/**
 * Perbaiki card pada mobile
 */
function fixMobileCards() {
    if (window.innerWidth < 768) {
        // Perbaiki padding pada card
        document.querySelectorAll('.card-body').forEach(function(cardBody) {
            cardBody.style.padding = '1rem';
        });
        
        // Perbaiki margin pada card
        document.querySelectorAll('.card').forEach(function(card) {
            card.style.marginBottom = '1rem';
        });
    } else {
        // Kembalikan padding pada card
        document.querySelectorAll('.card-body').forEach(function(cardBody) {
            cardBody.style.padding = '';
        });
        
        // Kembalikan margin pada card
        document.querySelectorAll('.card').forEach(function(card) {
            card.style.marginBottom = '';
        });
    }
}

/**
 * Perbaiki form pada mobile
 */
function fixMobileForms() {
    if (window.innerWidth < 768) {
        // Perbaiki padding pada form
        document.querySelectorAll('.form-group').forEach(function(formGroup) {
            formGroup.style.marginBottom = '0.75rem';
        });
        
        // Perbaiki ukuran font pada label
        document.querySelectorAll('.form-label').forEach(function(label) {
            label.style.fontSize = '0.9rem';
        });
        
        // Perbaiki padding pada input
        document.querySelectorAll('.form-control').forEach(function(input) {
            input.style.padding = '0.5rem 0.75rem';
        });
    } else {
        // Kembalikan padding pada form
        document.querySelectorAll('.form-group').forEach(function(formGroup) {
            formGroup.style.marginBottom = '';
        });
        
        // Kembalikan ukuran font pada label
        document.querySelectorAll('.form-label').forEach(function(label) {
            label.style.fontSize = '';
        });
        
        // Kembalikan padding pada input
        document.querySelectorAll('.form-control').forEach(function(input) {
            input.style.padding = '';
        });
    }
}