<?php
/**
 * Modern Notifications Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Redirect if not logged in
require_login();

$error = '';
$success = '';
$user_id = $_SESSION['user_id'];

// Process mark all as read
if (isset($_POST['mark_all_read'])) {
    try {
        $mark_all_sql = "UPDATE notifications SET is_read = 1 WHERE user_id = ?";
        $mark_all_stmt = $conn->prepare($mark_all_sql);
        $mark_all_stmt->bind_param("i", $user_id);
        
        if ($mark_all_stmt->execute()) {
            $success = "Semua notifikasi telah ditandai sebagai dibaca.";
        } else {
            $error = "Gagal menandai notifikasi sebagai dibaca: " . $conn->error;
        }
    } catch (Throwable $e) {
        $error = "Terjadi kesalahan: " . $e->getMessage();
    }
}

// Process mark as read
if (isset($_POST['mark_read']) && isset($_POST['notification_id'])) {
    $notification_id = intval($_POST['notification_id']);
    
    try {
        $mark_read_sql = "UPDATE notifications SET is_read = 1 WHERE notification_id = ? AND user_id = ?";
        $mark_read_stmt = $conn->prepare($mark_read_sql);
        $mark_read_stmt->bind_param("ii", $notification_id, $user_id);
        
        if ($mark_read_stmt->execute()) {
            $success = "Notifikasi telah ditandai sebagai dibaca.";
        } else {
            $error = "Gagal menandai notifikasi sebagai dibaca: " . $conn->error;
        }
    } catch (Throwable $e) {
        $error = "Terjadi kesalahan: " . $e->getMessage();
    }
}

// Process delete notification
if (isset($_POST['delete']) && isset($_POST['notification_id'])) {
    $notification_id = intval($_POST['notification_id']);
    
    try {
        $delete_sql = "DELETE FROM notifications WHERE notification_id = ? AND user_id = ?";
        $delete_stmt = $conn->prepare($delete_sql);
        $delete_stmt->bind_param("ii", $notification_id, $user_id);
        
        if ($delete_stmt->execute()) {
            $success = "Notifikasi telah dihapus.";
        } else {
            $error = "Gagal menghapus notifikasi: " . $conn->error;
        }
    } catch (Throwable $e) {
        $error = "Terjadi kesalahan: " . $e->getMessage();
    }
}

// Get notifications with pagination
$page = isset($_GET['page']) ? intval($_GET['page']) : 1;
$limit = 10;
$offset = ($page - 1) * $limit;

$filter = isset($_GET['filter']) ? $_GET['filter'] : 'all';
$filter_clause = '';

switch ($filter) {
    case 'unread':
        $filter_clause = " AND is_read = 0";
        break;
    case 'transaction':
    case 'payment':
    case 'alert':
    case 'system':
        $filter_clause = " AND type = '$filter'";
        break;
}

try {
    // Count total notifications
    $count_sql = "SELECT COUNT(*) as total FROM notifications WHERE user_id = ?$filter_clause";
    $count_stmt = $conn->prepare($count_sql);
    $count_stmt->bind_param("i", $user_id);
    $count_stmt->execute();
    $count_result = $count_stmt->get_result();
    $total_notifications = $count_result->fetch_assoc()['total'];
    
    $total_pages = ceil($total_notifications / $limit);
    
    // Get notifications
    $notifications_sql = "SELECT * FROM notifications 
                         WHERE user_id = ?$filter_clause 
                         ORDER BY created_at DESC 
                         LIMIT ? OFFSET ?";
    $notifications_stmt = $conn->prepare($notifications_sql);
    $notifications_stmt->bind_param("iii", $user_id, $limit, $offset);
    $notifications_stmt->execute();
    $notifications_result = $notifications_stmt->get_result();
    
    $notifications = [];
    while ($row = $notifications_result->fetch_assoc()) {
        $notifications[] = $row;
    }
    
    // Count unread notifications
    $unread_sql = "SELECT COUNT(*) as unread FROM notifications WHERE user_id = ? AND is_read = 0";
    $unread_stmt = $conn->prepare($unread_sql);
    $unread_stmt->bind_param("i", $user_id);
    $unread_stmt->execute();
    $unread_result = $unread_stmt->get_result();
    $unread_count = $unread_result->fetch_assoc()['unread'];
    
} catch (Throwable $e) {
    $error = "Gagal memuat notifikasi: " . $e->getMessage();
    $notifications = [];
    $total_pages = 0;
    $unread_count = 0;
}

// Set page title and flags
$page_title = "Notifikasi";
$is_dashboard_page = true;
$use_modern_dashboard = true;
$page_specific_css = '<link href="css/notification-2025.css" rel="stylesheet">';

// Include header
include("includes/header-2025.php");
?>

<!-- Main Content Container -->
<div class="container-fluid py-5">
    <?php if (!empty($success)): ?>
    <div class="alert-2025 alert-2025-success mb-4 slide-down">
        <i class="fa fa-check-circle"></i>
        <div><?php echo $success; ?></div>
    </div>
    <?php endif; ?>
    
    <?php if (!empty($error)): ?>
    <div class="alert-2025 alert-2025-danger mb-4 slide-down">
        <i class="fa fa-exclamation-circle"></i>
        <div><?php echo $error; ?></div>
    </div>
    <?php endif; ?>
    
    <div class="row">
        <!-- Sidebar Navigation -->
        <div class="col-lg-3">
            <?php include("includes/account-navbar.php"); ?>
        </div>
        
        <!-- Main Content -->
        <div class="col-lg-9">
            <div class="notification-center-2025">
                <div class="notification-center-2025-header">
                    <h2 class="notification-center-2025-title gradient-text">Notifikasi</h2>
                    <p class="notification-center-2025-subtitle">Lihat semua pemberitahuan dan aktivitas terbaru Anda</p>
                </div>
                
                <div class="d-flex justify-content-between align-items-center mb-4">
                    <div class="notification-stats">
                        <span class="badge-2025 badge-2025-soft-primary badge-2025-pill me-2">
                            Total: <?php echo $total_notifications; ?>
                        </span>
                        <?php if ($unread_count > 0): ?>
                        <span class="badge-2025 badge-2025-soft-danger badge-2025-pill">
                            Belum dibaca: <?php echo $unread_count; ?>
                        </span>
                        <?php endif; ?>
                    </div>
                    
                    <div class="notification-actions">
                        <?php if ($unread_count > 0): ?>
                        <form method="post" action="" class="d-inline">
                            <input type="hidden" name="mark_all_read" value="1">
                            <button type="submit" class="btn-2025 btn-2025-sm btn-2025-outline me-2">
                                <i class="fa fa-check-double me-1"></i> Tandai Semua Dibaca
                            </button>
                        </form>
                        <?php endif; ?>
                        
                        <div class="dropdown-2025 d-inline-block">
                            <button class="btn-2025 btn-2025-sm btn-2025-primary dropdown-2025-toggle">
                                <i class="fa fa-filter me-1"></i> Filter
                                <i class="fa fa-chevron-down ms-1"></i>
                            </button>
                            <ul class="dropdown-2025-menu dropdown-2025-menu-right">
                                <li><a href="?filter=all" class="<?php echo $filter == 'all' ? 'active' : ''; ?>">Semua</a></li>
                                <li><a href="?filter=unread" class="<?php echo $filter == 'unread' ? 'active' : ''; ?>">Belum Dibaca</a></li>
                                <li><a href="?filter=transaction" class="<?php echo $filter == 'transaction' ? 'active' : ''; ?>">Transaksi</a></li>
                                <li><a href="?filter=payment" class="<?php echo $filter == 'payment' ? 'active' : ''; ?>">Pembayaran</a></li>
                                <li><a href="?filter=alert" class="<?php echo $filter == 'alert' ? 'active' : ''; ?>">Peringatan</a></li>
                                <li><a href="?filter=system" class="<?php echo $filter == 'system' ? 'active' : ''; ?>">Sistem</a></li>
                            </ul>
                        </div>
                    </div>
                </div>
                
                <?php if (empty($notifications)): ?>
                <div class="card-2025 text-center py-5">
                    <div class="empty-state">
                        <i class="fa fa-bell-slash fa-4x text-muted mb-3"></i>
                        <h4>Tidak Ada Notifikasi</h4>
                        <p class="text-muted">Anda belum memiliki notifikasi <?php echo $filter != 'all' ? 'dengan filter ini' : ''; ?>.</p>
                    </div>
                </div>
                <?php else: ?>
                <div class="notification-center-2025-list">
                    <?php foreach ($notifications as $notification): ?>
                    <div class="notification-center-2025-item <?php echo $notification['is_read'] ? '' : 'unread'; ?> scroll-reveal">
                        <div class="notification-center-2025-item-icon <?php echo $notification['type']; ?>">
                            <?php
                            switch ($notification['type']) {
                                case 'transaction':
                                    echo '<i class="fa fa-exchange-alt"></i>';
                                    break;
                                case 'payment':
                                    echo '<i class="fa fa-credit-card"></i>';
                                    break;
                                case 'alert':
                                    echo '<i class="fa fa-exclamation-circle"></i>';
                                    break;
                                case 'system':
                                    echo '<i class="fa fa-cog"></i>';
                                    break;
                                default:
                                    echo '<i class="fa fa-bell"></i>';
                            }
                            ?>
                        </div>
                        <div class="notification-center-2025-item-content">
                            <div class="notification-center-2025-item-title"><?php echo htmlspecialchars($notification['title']); ?></div>
                            <div class="notification-center-2025-item-message"><?php echo htmlspecialchars($notification['message']); ?></div>
                            <div class="notification-center-2025-item-time"><?php echo format_time_ago($notification['created_at']); ?></div>
                            
                            <div class="notification-center-2025-item-actions">
                                <?php if (!$notification['is_read']): ?>
                                <form method="post" action="" class="d-inline">
                                    <input type="hidden" name="mark_read" value="1">
                                    <input type="hidden" name="notification_id" value="<?php echo $notification['notification_id']; ?>">
                                    <button type="submit" class="mark-read">
                                        <i class="fa fa-check me-1"></i> Tandai Dibaca
                                    </button>
                                </form>
                                <?php endif; ?>
                                
                                <form method="post" action="" class="d-inline delete-notification-form">
                                    <input type="hidden" name="delete" value="1">
                                    <input type="hidden" name="notification_id" value="<?php echo $notification['notification_id']; ?>">
                                    <button type="submit" class="delete">
                                        <i class="fa fa-trash me-1"></i> Hapus
                                    </button>
                                </form>
                            </div>
                        </div>
                    </div>
                    <?php endforeach; ?>
                </div>
                
                <!-- Pagination -->
                <?php if ($total_pages > 1): ?>
                <div class="pagination-2025 mt-4">
                    <ul>
                        <?php if ($page > 1): ?>
                        <li>
                            <a href="?page=<?php echo $page - 1; ?>&filter=<?php echo $filter; ?>" class="pagination-2025-prev">
                                <i class="fa fa-chevron-left"></i>
                            </a>
                        </li>
                        <?php endif; ?>
                        
                        <?php
                        $start_page = max(1, $page - 2);
                        $end_page = min($total_pages, $page + 2);
                        
                        if ($start_page > 1) {
                            echo '<li><a href="?page=1&filter='.$filter.'">1</a></li>';
                            if ($start_page > 2) {
                                echo '<li><span class="pagination-2025-dots">...</span></li>';
                            }
                        }
                        
                        for ($i = $start_page; $i <= $end_page; $i++) {
                            echo '<li><a href="?page='.$i.'&filter='.$filter.'" class="'.($i == $page ? 'active' : '').'">'.$i.'</a></li>';
                        }
                        
                        if ($end_page < $total_pages) {
                            if ($end_page < $total_pages - 1) {
                                echo '<li><span class="pagination-2025-dots">...</span></li>';
                            }
                            echo '<li><a href="?page='.$total_pages.'&filter='.$filter.'">'.$total_pages.'</a></li>';
                        }
                        ?>
                        
                        <?php if ($page < $total_pages): ?>
                        <li>
                            <a href="?page=<?php echo $page + 1; ?>&filter=<?php echo $filter; ?>" class="pagination-2025-next">
                                <i class="fa fa-chevron-right"></i>
                            </a>
                        </li>
                        <?php endif; ?>
                    </ul>
                </div>
                <?php endif; ?>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>

<style>
/* Pagination 2025 */
.pagination-2025 {
    display: flex;
    justify-content: center;
    margin-top: 30px;
}

.pagination-2025 ul {
    display: flex;
    list-style: none;
    padding: 0;
    margin: 0;
    gap: 5px;
}

.pagination-2025 li {
    margin: 0;
}

.pagination-2025 a,
.pagination-2025-dots {
    display: flex;
    align-items: center;
    justify-content: center;
    width: 40px;
    height: 40px;
    border-radius: var(--border-radius);
    color: var(--text-color);
    text-decoration: none;
    transition: var(--transition-fast);
    font-weight: 500;
}

.pagination-2025 a:hover {
    background-color: rgba(67, 97, 238, 0.1);
    color: var(--primary);
}

.pagination-2025 a.active {
    background-color: var(--primary);
    color: white;
}

.pagination-2025-prev,
.pagination-2025-next {
    background-color: rgba(67, 97, 238, 0.1);
    color: var(--primary);
}

.pagination-2025-dots {
    color: var(--text-color-light);
}

/* Empty State */
.empty-state {
    padding: 30px;
    text-align: center;
}

.empty-state i {
    color: #ddd;
}

body.dark-mode .empty-state i {
    color: #475569;
}

/* Delete Notification Form */
.delete-notification-form button {
    background: none;
    border: none;
    cursor: pointer;
}
</style>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Confirm delete notification
    const deleteNotificationForms = document.querySelectorAll('.delete-notification-form');
    deleteNotificationForms.forEach(form => {
        form.addEventListener('submit', function(e) {
            if (!confirm('Apakah Anda yakin ingin menghapus notifikasi ini?')) {
                e.preventDefault();
            }
        });
    });
});
</script>

<?php include("includes/footer-2025.php"); ?>