<?php
/**
 * Notifications Page
 * LelangMobil Web App - Versi 2025
 */

// Include initialization file
require_once 'config/init.php';

// Redirect if not logged in
require_login();

$user_id = $_SESSION['user_id'];
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$limit = 20;
$offset = ($page - 1) * $limit;

// Get notifications
try {
    $sql = "SELECT * FROM notifications 
            WHERE user_id = ? 
            ORDER BY created_at DESC 
            LIMIT ? OFFSET ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("iii", $user_id, $limit, $offset);
    $stmt->execute();
    $notifications_result = $stmt->get_result();
    
    // Count total notifications
    $count_sql = "SELECT COUNT(*) as total FROM notifications WHERE user_id = ?";
    $count_stmt = $conn->prepare($count_sql);
    $count_stmt->bind_param("i", $user_id);
    $count_stmt->execute();
    $count_result = $count_stmt->get_result();
    $total_notifications = $count_result->fetch_assoc()['total'];
    
    $total_pages = ceil($total_notifications / $limit);
} catch (Exception $e) {
    $error = "Error fetching notifications: " . $e->getMessage();
}

// Mark all as read
if (isset($_GET['mark_all_read'])) {
    try {
        $sql = "UPDATE notifications SET is_read = 1 WHERE user_id = ? AND is_read = 0";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $user_id);
        $stmt->execute();
        
        header("Location: notifications.php?success=marked_all_read");
        exit;
    } catch (Exception $e) {
        $error = "Error marking notifications as read: " . $e->getMessage();
    }
}

// Mark single notification as read
if (isset($_GET['mark_read']) && is_numeric($_GET['mark_read'])) {
    try {
        $notification_id = (int)$_GET['mark_read'];
        
        $sql = "UPDATE notifications SET is_read = 1 WHERE notification_id = ? AND user_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ii", $notification_id, $user_id);
        $stmt->execute();
        
        header("Location: notifications.php?success=marked_read");
        exit;
    } catch (Exception $e) {
        $error = "Error marking notification as read: " . $e->getMessage();
    }
}

// Delete notification
if (isset($_GET['delete']) && is_numeric($_GET['delete'])) {
    try {
        $notification_id = (int)$_GET['delete'];
        
        $sql = "DELETE FROM notifications WHERE notification_id = ? AND user_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ii", $notification_id, $user_id);
        $stmt->execute();
        
        header("Location: notifications.php?success=deleted");
        exit;
    } catch (Exception $e) {
        $error = "Error deleting notification: " . $e->getMessage();
    }
}

// Delete all notifications
if (isset($_GET['delete_all'])) {
    try {
        $sql = "DELETE FROM notifications WHERE user_id = ?";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("i", $user_id);
        $stmt->execute();
        
        header("Location: notifications.php?success=deleted_all");
        exit;
    } catch (Exception $e) {
        $error = "Error deleting notifications: " . $e->getMessage();
    }
}

// Success messages
$success = '';
if (isset($_GET['success'])) {
    switch ($_GET['success']) {
        case 'marked_read':
            $success = "Notifikasi ditandai sebagai dibaca.";
            break;
        case 'marked_all_read':
            $success = "Semua notifikasi ditandai sebagai dibaca.";
            break;
        case 'deleted':
            $success = "Notifikasi berhasil dihapus.";
            break;
        case 'deleted_all':
            $success = "Semua notifikasi berhasil dihapus.";
            break;
    }
}

// Page title
$page_title = "Notifikasi";
$use_ultra_modern = true;

// Include header
include("includes/header.php");
?>

<div class="container-fluid py-5">
    <div class="row">
        <!-- Sidebar Navigation -->
        <div class="col-lg-3">
            <?php include("includes/account-navbar.php"); ?>
        </div>
        
        <!-- Main Content -->
        <div class="col-lg-9">
            <div class="d-flex justify-content-between align-items-center mb-4">
                <h2 class="mb-0">Notifikasi</h2>
                <div>
                    <a href="notifications.php?mark_all_read=1" class="modern-button modern-button-outline me-2">
                        <i class="fa fa-check-double me-2"></i>Tandai Semua Dibaca
                    </a>
                    <a href="notifications.php?delete_all=1" class="modern-button modern-button-danger" onclick="return confirm('Apakah Anda yakin ingin menghapus semua notifikasi?')">
                        <i class="fa fa-trash me-2"></i>Hapus Semua
                    </a>
                </div>
            </div>
            
            <?php if (!empty($success)): ?>
            <div class="modern-alert modern-alert-success mb-4 fade-in">
                <i class="fa fa-check-circle"></i>
                <div><?php echo $success; ?></div>
            </div>
            <?php endif; ?>
            
            <?php if (!empty($error)): ?>
            <div class="modern-alert modern-alert-danger mb-4 fade-in">
                <i class="fa fa-exclamation-circle"></i>
                <div><?php echo $error; ?></div>
            </div>
            <?php endif; ?>
            
            <div class="modern-card fade-in">
                <div class="modern-card-body p-0">
                    <?php if ($notifications_result && $notifications_result->num_rows > 0): ?>
                        <div class="notification-list-page">
                            <?php while ($notification = $notifications_result->fetch_assoc()): ?>
                                <div class="notification-item <?php echo $notification['is_read'] ? '' : 'unread'; ?>">
                                    <div class="notification-icon">
                                        <i class="fa <?php echo getNotificationIcon($notification['type']); ?>"></i>
                                    </div>
                                    <div class="notification-content">
                                        <div class="notification-title"><?php echo htmlspecialchars($notification['title']); ?></div>
                                        <div class="notification-message"><?php echo htmlspecialchars($notification['message']); ?></div>
                                        <div class="notification-time"><?php echo formatTimeAgo($notification['created_at']); ?></div>
                                    </div>
                                    <div class="notification-actions">
                                        <?php if (!$notification['is_read']): ?>
                                            <a href="notifications.php?mark_read=<?php echo $notification['notification_id']; ?>" class="btn btn-sm btn-outline-primary me-2" title="Tandai Dibaca">
                                                <i class="fa fa-check"></i>
                                            </a>
                                        <?php endif; ?>
                                        <?php if ($notification['url']): ?>
                                            <a href="<?php echo htmlspecialchars($notification['url']); ?>" class="btn btn-sm btn-outline-info me-2" title="Lihat Detail">
                                                <i class="fa fa-eye"></i>
                                            </a>
                                        <?php endif; ?>
                                        <a href="notifications.php?delete=<?php echo $notification['notification_id']; ?>" class="btn btn-sm btn-outline-danger" title="Hapus" onclick="return confirm('Apakah Anda yakin ingin menghapus notifikasi ini?')">
                                            <i class="fa fa-trash"></i>
                                        </a>
                                    </div>
                                </div>
                            <?php endwhile; ?>
                        </div>
                        
                        <?php if ($total_pages > 1): ?>
                            <div class="pagination-container p-3 border-top">
                                <nav aria-label="Page navigation">
                                    <ul class="pagination justify-content-center mb-0">
                                        <?php if ($page > 1): ?>
                                            <li class="page-item">
                                                <a class="page-link" href="notifications.php?page=<?php echo $page - 1; ?>" aria-label="Previous">
                                                    <span aria-hidden="true">&laquo;</span>
                                                </a>
                                            </li>
                                        <?php endif; ?>
                                        
                                        <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                                            <li class="page-item <?php echo $i == $page ? 'active' : ''; ?>">
                                                <a class="page-link" href="notifications.php?page=<?php echo $i; ?>"><?php echo $i; ?></a>
                                            </li>
                                        <?php endfor; ?>
                                        
                                        <?php if ($page < $total_pages): ?>
                                            <li class="page-item">
                                                <a class="page-link" href="notifications.php?page=<?php echo $page + 1; ?>" aria-label="Next">
                                                    <span aria-hidden="true">&raquo;</span>
                                                </a>
                                            </li>
                                        <?php endif; ?>
                                    </ul>
                                </nav>
                            </div>
                        <?php endif; ?>
                    <?php else: ?>
                        <div class="text-center p-5">
                            <div class="mb-4">
                                <i class="fa fa-bell-slash fa-4x text-muted"></i>
                            </div>
                            <h4>Tidak Ada Notifikasi</h4>
                            <p class="text-muted">Anda belum memiliki notifikasi.</p>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<style>
.notification-list-page .notification-item {
    padding: 15px;
    border-bottom: 1px solid rgba(0, 0, 0, 0.05);
    display: flex;
    align-items: flex-start;
}

.notification-list-page .notification-item:last-child {
    border-bottom: none;
}

.notification-list-page .notification-item.unread {
    background-color: rgba(59, 130, 246, 0.05);
}

.notification-list-page .notification-icon {
    width: 40px;
    height: 40px;
    border-radius: 50%;
    background-color: rgba(59, 130, 246, 0.1);
    display: flex;
    align-items: center;
    justify-content: center;
    margin-right: 15px;
    flex-shrink: 0;
}

.notification-list-page .notification-content {
    flex: 1;
}

.notification-list-page .notification-actions {
    margin-left: 15px;
    display: flex;
    align-items: center;
}

body.dark-theme .notification-list-page .notification-item {
    border-bottom-color: rgba(255, 255, 255, 0.1);
}

body.dark-theme .notification-list-page .notification-item.unread {
    background-color: rgba(59, 130, 246, 0.1);
}
</style>

<?php
// Helper functions
function getNotificationIcon($type) {
    $icons = [
        'bid' => 'fa-gavel',
        'transaction' => 'fa-money-bill-wave',
        'system' => 'fa-cog',
        'auction' => 'fa-car',
        'auto_bid' => 'fa-robot',
        'payment' => 'fa-credit-card',
        'withdrawal' => 'fa-wallet'
    ];
    
    return $icons[$type] ?? 'fa-bell';
}

function formatTimeAgo($datetime) {
    $now = new DateTime();
    $date = new DateTime($datetime);
    $interval = $now->diff($date);
    
    if ($interval->y >= 1) {
        return $interval->y . ' tahun yang lalu';
    } elseif ($interval->m >= 1) {
        return $interval->m . ' bulan yang lalu';
    } elseif ($interval->d >= 1) {
        return $interval->d . ' hari yang lalu';
    } elseif ($interval->h >= 1) {
        return $interval->h . ' jam yang lalu';
    } elseif ($interval->i >= 1) {
        return $interval->i . ' menit yang lalu';
    } else {
        return 'baru saja';
    }
}

include("includes/footer.php");
?>