-- Auto-bidding table
CREATE TABLE IF NOT EXISTS auto_bids (
    auto_bid_id INT PRIMARY KEY AUTO_INCREMENT,
    user_id INT NOT NULL,
    vehicle_id INT NOT NULL,
    max_amount DECIMAL(15,2) NOT NULL,
    bid_increment DECIMAL(15,2) NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    status ENUM('active', 'completed', 'cancelled') DEFAULT 'active',
    FOREIGN KEY (user_id) REFERENCES users(user_id),
    FOREIGN KEY (vehicle_id) REFERENCES vehicles(vehicle_id),
    UNIQUE KEY unique_user_vehicle (user_id, vehicle_id)
);

-- Auto-bid logs table
CREATE TABLE IF NOT EXISTS auto_bid_logs (
    log_id INT PRIMARY KEY AUTO_INCREMENT,
    auto_bid_id INT NOT NULL,
    bid_amount DECIMAL(15,2) NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    status ENUM('success', 'failed') DEFAULT 'success',
    error_message TEXT,
    FOREIGN KEY (auto_bid_id) REFERENCES auto_bids(auto_bid_id)
);

-- Add WebSocket notification preferences
ALTER TABLE users 
ADD COLUMN notification_preferences JSON DEFAULT '{"email": true, "websocket": true, "bid_alerts": true}',
ADD COLUMN websocket_token VARCHAR(255);

-- Add favorite vehicles table
CREATE TABLE IF NOT EXISTS favorite_vehicles (
    favorite_id INT PRIMARY KEY AUTO_INCREMENT,
    user_id INT NOT NULL,
    vehicle_id INT NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (user_id) REFERENCES users(user_id),
    FOREIGN KEY (vehicle_id) REFERENCES vehicles(vehicle_id),
    UNIQUE KEY unique_user_vehicle_fav (user_id, vehicle_id)
);

-- Add rating system tables
CREATE TABLE IF NOT EXISTS user_ratings (
    rating_id INT PRIMARY KEY AUTO_INCREMENT,
    from_user_id INT NOT NULL,
    to_user_id INT NOT NULL,
    rating INT NOT NULL CHECK (rating BETWEEN 1 AND 5),
    comment TEXT,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    FOREIGN KEY (from_user_id) REFERENCES users(user_id),
    FOREIGN KEY (to_user_id) REFERENCES users(user_id),
    UNIQUE KEY unique_rating (from_user_id, to_user_id)
);

-- Add vehicle comments table
CREATE TABLE IF NOT EXISTS vehicle_comments (
    comment_id INT PRIMARY KEY AUTO_INCREMENT,
    vehicle_id INT NOT NULL,
    user_id INT NOT NULL,
    comment TEXT NOT NULL,
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    status ENUM('pending', 'approved', 'rejected') DEFAULT 'pending',
    FOREIGN KEY (vehicle_id) REFERENCES vehicles(vehicle_id),
    FOREIGN KEY (user_id) REFERENCES users(user_id)
);

-- Add indexes for performance
CREATE INDEX idx_auto_bids_status ON auto_bids(status);
CREATE INDEX idx_vehicle_comments_status ON vehicle_comments(status);
CREATE INDEX idx_user_ratings_to_user ON user_ratings(to_user_id);