<?php
/**
 * System Status
 * LelangMobil Web App - Versi 2025
 * 
 * File ini menampilkan status sistem dan performa
 */

// Include initialization file
require_once 'config/init.php';

// Set page title
$page_title = "System Status";

// Custom CSS
$page_specific_css = '<style>
    .status-card {
        border-radius: 8px;
        padding: 20px;
        margin-bottom: 20px;
        background-color: var(--card-bg);
        box-shadow: var(--box-shadow);
    }
    .status-card h3 {
        margin-top: 0;
        border-bottom: 1px solid rgba(0,0,0,0.1);
        padding-bottom: 10px;
        margin-bottom: 15px;
    }
    .status-item {
        display: flex;
        justify-content: space-between;
        margin-bottom: 10px;
        padding-bottom: 10px;
        border-bottom: 1px solid rgba(0,0,0,0.05);
    }
    .status-item:last-child {
        border-bottom: none;
        margin-bottom: 0;
        padding-bottom: 0;
    }
    .status-label {
        font-weight: 500;
    }
    .status-value {
        font-weight: 600;
    }
    .status-good {
        color: var(--success);
    }
    .status-warning {
        color: var(--warning);
    }
    .status-error {
        color: var(--danger);
    }
    .progress {
        height: 8px;
        margin-top: 5px;
        border-radius: 4px;
        background-color: rgba(0,0,0,0.1);
        overflow: hidden;
    }
    .progress-bar {
        height: 100%;
        border-radius: 4px;
    }
    .progress-bar-good {
        background-color: var(--success);
    }
    .progress-bar-warning {
        background-color: var(--warning);
    }
    .progress-bar-error {
        background-color: var(--danger);
    }
</style>';

// Include header
include("includes/header.php");

// Get system status
$system_status = [
    'php_version' => PHP_VERSION,
    'mysql_version' => $conn->server_info,
    'server_software' => $_SERVER['SERVER_SOFTWARE'] ?? 'Unknown',
    'memory_limit' => ini_get('memory_limit'),
    'max_execution_time' => ini_get('max_execution_time'),
    'upload_max_filesize' => ini_get('upload_max_filesize'),
    'post_max_size' => ini_get('post_max_size'),
    'disk_free_space' => disk_free_space('/'),
    'disk_total_space' => disk_total_space('/')
];

// Get database status
$db_status = [
    'users_count' => db_get_row("SELECT COUNT(*) as count FROM users")['count'] ?? 0,
    'vehicles_count' => db_get_row("SELECT COUNT(*) as count FROM vehicles")['count'] ?? 0,
    'bids_count' => db_get_row("SELECT COUNT(*) as count FROM bids")['count'] ?? 0,
    'transactions_count' => db_get_row("SELECT COUNT(*) as count FROM transactions")['count'] ?? 0,
    'active_auctions' => db_get_row("SELECT COUNT(*) as count FROM vehicles WHERE status = 'active'")['count'] ?? 0,
    'pending_transactions' => db_get_row("SELECT COUNT(*) as count FROM transactions WHERE status = 'pending'")['count'] ?? 0
];

// Get cache status
$cache_status = [
    'cache_enabled' => class_exists('Cache'),
    'cache_files' => count(glob(dirname(__FILE__) . '/cache/*.cache')),
    'cache_size' => array_sum(array_map('filesize', glob(dirname(__FILE__) . '/cache/*.cache') ?: []))
];

// Get error log status
$error_log_status = [
    'log_exists' => file_exists(dirname(__FILE__) . '/logs/error.log'),
    'log_size' => file_exists(dirname(__FILE__) . '/logs/error.log') ? filesize(dirname(__FILE__) . '/logs/error.log') : 0,
    'log_modified' => file_exists(dirname(__FILE__) . '/logs/error.log') ? filemtime(dirname(__FILE__) . '/logs/error.log') : 0,
    'error_count' => file_exists(dirname(__FILE__) . '/logs/error.log') ? count(file(dirname(__FILE__) . '/logs/error.log')) : 0
];

// Get image cache status
$image_cache_status = [
    'cache_enabled' => function_exists('get_optimized_image'),
    'cache_files' => count(glob(dirname(__FILE__) . '/cache/images/*')),
    'cache_size' => array_sum(array_map('filesize', glob(dirname(__FILE__) . '/cache/images/*') ?: []))
];

// Get minifier status
$minifier_status = [
    'minifier_enabled' => function_exists('get_minified_css'),
    'minified_files' => count(glob(dirname(__FILE__) . '/cache/minified/*')),
    'minified_size' => array_sum(array_map('filesize', glob(dirname(__FILE__) . '/cache/minified/*') ?: []))
];
?>

<div class="container py-5">
    <div class="row">
        <div class="col-lg-8 offset-lg-2">
            <h1 class="mb-4">System Status</h1>
            
            <div class="status-card">
                <h3>System Information</h3>
                <div class="status-item">
                    <div class="status-label">PHP Version</div>
                    <div class="status-value"><?php echo $system_status['php_version']; ?></div>
                </div>
                <div class="status-item">
                    <div class="status-label">MySQL Version</div>
                    <div class="status-value"><?php echo $system_status['mysql_version']; ?></div>
                </div>
                <div class="status-item">
                    <div class="status-label">Server Software</div>
                    <div class="status-value"><?php echo $system_status['server_software']; ?></div>
                </div>
                <div class="status-item">
                    <div class="status-label">Memory Limit</div>
                    <div class="status-value"><?php echo $system_status['memory_limit']; ?></div>
                </div>
                <div class="status-item">
                    <div class="status-label">Max Execution Time</div>
                    <div class="status-value"><?php echo $system_status['max_execution_time']; ?> seconds</div>
                </div>
                <div class="status-item">
                    <div class="status-label">Upload Max Filesize</div>
                    <div class="status-value"><?php echo $system_status['upload_max_filesize']; ?></div>
                </div>
                <div class="status-item">
                    <div class="status-label">Post Max Size</div>
                    <div class="status-value"><?php echo $system_status['post_max_size']; ?></div>
                </div>
                <div class="status-item">
                    <div class="status-label">Disk Space</div>
                    <div class="status-value">
                        <?php 
                        $disk_free = $system_status['disk_free_space'];
                        $disk_total = $system_status['disk_total_space'];
                        $disk_used = $disk_total - $disk_free;
                        $disk_percent = round(($disk_used / $disk_total) * 100);
                        
                        $status_class = 'status-good';
                        $progress_class = 'progress-bar-good';
                        
                        if ($disk_percent > 70) {
                            $status_class = 'status-warning';
                            $progress_class = 'progress-bar-warning';
                        }
                        
                        if ($disk_percent > 90) {
                            $status_class = 'status-error';
                            $progress_class = 'progress-bar-error';
                        }
                        
                        echo '<span class="' . $status_class . '">' . number_format($disk_free / 1024 / 1024 / 1024, 2) . ' GB free of ' . number_format($disk_total / 1024 / 1024 / 1024, 2) . ' GB</span>';
                        ?>
                        <div class="progress">
                            <div class="progress-bar <?php echo $progress_class; ?>" style="width: <?php echo $disk_percent; ?>%"></div>
                        </div>
                    </div>
                </div>
            </div>
            
            <div class="status-card">
                <h3>Database Status</h3>
                <div class="status-item">
                    <div class="status-label">Users</div>
                    <div class="status-value"><?php echo number_format($db_status['users_count']); ?></div>
                </div>
                <div class="status-item">
                    <div class="status-label">Vehicles</div>
                    <div class="status-value"><?php echo number_format($db_status['vehicles_count']); ?></div>
                </div>
                <div class="status-item">
                    <div class="status-label">Bids</div>
                    <div class="status-value"><?php echo number_format($db_status['bids_count']); ?></div>
                </div>
                <div class="status-item">
                    <div class="status-label">Transactions</div>
                    <div class="status-value"><?php echo number_format($db_status['transactions_count']); ?></div>
                </div>
                <div class="status-item">
                    <div class="status-label">Active Auctions</div>
                    <div class="status-value"><?php echo number_format($db_status['active_auctions']); ?></div>
                </div>
                <div class="status-item">
                    <div class="status-label">Pending Transactions</div>
                    <div class="status-value">
                        <?php 
                        $pending_count = $db_status['pending_transactions'];
                        $status_class = 'status-good';
                        
                        if ($pending_count > 10) {
                            $status_class = 'status-warning';
                        }
                        
                        if ($pending_count > 50) {
                            $status_class = 'status-error';
                        }
                        
                        echo '<span class="' . $status_class . '">' . number_format($pending_count) . '</span>';
                        ?>
                    </div>
                </div>
            </div>
            
            <div class="row">
                <div class="col-md-6">
                    <div class="status-card">
                        <h3>Cache Status</h3>
                        <div class="status-item">
                            <div class="status-label">Cache Enabled</div>
                            <div class="status-value">
                                <?php echo $cache_status['cache_enabled'] ? '<span class="status-good">Yes</span>' : '<span class="status-error">No</span>'; ?>
                            </div>
                        </div>
                        <div class="status-item">
                            <div class="status-label">Cache Files</div>
                            <div class="status-value"><?php echo number_format($cache_status['cache_files']); ?></div>
                        </div>
                        <div class="status-item">
                            <div class="status-label">Cache Size</div>
                            <div class="status-value"><?php echo number_format($cache_status['cache_size'] / 1024, 2); ?> KB</div>
                        </div>
                    </div>
                </div>
                
                <div class="col-md-6">
                    <div class="status-card">
                        <h3>Error Log Status</h3>
                        <div class="status-item">
                            <div class="status-label">Log Exists</div>
                            <div class="status-value">
                                <?php echo $error_log_status['log_exists'] ? '<span class="status-good">Yes</span>' : '<span class="status-warning">No</span>'; ?>
                            </div>
                        </div>
                        <div class="status-item">
                            <div class="status-label">Log Size</div>
                            <div class="status-value"><?php echo number_format($error_log_status['log_size'] / 1024, 2); ?> KB</div>
                        </div>
                        <div class="status-item">
                            <div class="status-label">Last Modified</div>
                            <div class="status-value">
                                <?php echo $error_log_status['log_modified'] ? date('Y-m-d H:i:s', $error_log_status['log_modified']) : 'N/A'; ?>
                            </div>
                        </div>
                        <div class="status-item">
                            <div class="status-label">Error Count</div>
                            <div class="status-value">
                                <?php 
                                $error_count = $error_log_status['error_count'];
                                $status_class = 'status-good';
                                
                                if ($error_count > 10) {
                                    $status_class = 'status-warning';
                                }
                                
                                if ($error_count > 50) {
                                    $status_class = 'status-error';
                                }
                                
                                echo '<span class="' . $status_class . '">' . number_format($error_count) . '</span>';
                                ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            
            <div class="row">
                <div class="col-md-6">
                    <div class="status-card">
                        <h3>Image Cache Status</h3>
                        <div class="status-item">
                            <div class="status-label">Image Optimizer Enabled</div>
                            <div class="status-value">
                                <?php echo $image_cache_status['cache_enabled'] ? '<span class="status-good">Yes</span>' : '<span class="status-error">No</span>'; ?>
                            </div>
                        </div>
                        <div class="status-item">
                            <div class="status-label">Cached Images</div>
                            <div class="status-value"><?php echo number_format($image_cache_status['cache_files']); ?></div>
                        </div>
                        <div class="status-item">
                            <div class="status-label">Cache Size</div>
                            <div class="status-value"><?php echo number_format($image_cache_status['cache_size'] / 1024, 2); ?> KB</div>
                        </div>
                    </div>
                </div>
                
                <div class="col-md-6">
                    <div class="status-card">
                        <h3>Minifier Status</h3>
                        <div class="status-item">
                            <div class="status-label">Minifier Enabled</div>
                            <div class="status-value">
                                <?php echo $minifier_status['minifier_enabled'] ? '<span class="status-good">Yes</span>' : '<span class="status-error">No</span>'; ?>
                            </div>
                        </div>
                        <div class="status-item">
                            <div class="status-label">Minified Files</div>
                            <div class="status-value"><?php echo number_format($minifier_status['minified_files']); ?></div>
                        </div>
                        <div class="status-item">
                            <div class="status-label">Minified Size</div>
                            <div class="status-value"><?php echo number_format($minifier_status['minified_size'] / 1024, 2); ?> KB</div>
                        </div>
                    </div>
                </div>
            </div>
            
            <div class="text-center mt-4">
                <a href="test-system.php" class="modern-btn modern-btn-primary">Run System Test</a>
                <a href="index.php" class="modern-btn modern-btn-outline ms-2">Back to Home</a>
            </div>
        </div>
    </div>
</div>

<?php include("includes/footer.php"); ?>